# coding: utf-8

"""
    SmartyMeet Dev03 API REST

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0.1
    Contact: developer@smartymeet.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from smartytalent_client.api.ads_api import AdsApi


class TestAdsApi(unittest.TestCase):
    """AdsApi unit test stubs"""

    def setUp(self) -> None:
        self.api = AdsApi()

    def tearDown(self) -> None:
        pass

    def test_ad_options(self) -> None:
        """Test case for ad_options

        Ad Options
        """
        pass

    def test_ads_options(self) -> None:
        """Test case for ads_options

        Ads Options
        """
        pass

    def test_create_ad(self) -> None:
        """Test case for create_ad

        Create Ad
        """
        pass

    def test_delete_ad(self) -> None:
        """Test case for delete_ad

        Delete Ad
        """
        pass

    def test_list_ads(self) -> None:
        """Test case for list_ads

        List Ads
        """
        pass

    def test_show_ad(self) -> None:
        """Test case for show_ad

        Show Ad
        """
        pass

    def test_update_ad(self) -> None:
        """Test case for update_ad

        Update Ad
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    SmartyMeet Dev03 API REST

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0.1
    Contact: developer@smartymeet.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from smartytalent_client.models.update_meeting_request_body import UpdateMeetingRequestBody

class TestUpdateMeetingRequestBody(unittest.TestCase):
    """UpdateMeetingRequestBody unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> UpdateMeetingRequestBody:
        """Test UpdateMeetingRequestBody
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `UpdateMeetingRequestBody`
        """
        model = UpdateMeetingRequestBody()
        if include_optional:
            return UpdateMeetingRequestBody(
                data = smartytalent_client.models.update_meeting_request_body_data.UpdateMeetingRequestBodyData(
                    type = 'meetings', 
                    id = '', 
                    attributes = smartytalent_client.models.meeting_attributes_schema.MeetingAttributesSchema(
                        title = '', 
                        description = '', 
                        scheduled_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        duration = 56, 
                        media_region = '', 
                        external_meeting_id = '', 
                        chime_meeting_id = '', 
                        chime_meeting_data = smartytalent_client.models.chime_meeting_data.chimeMeetingData(), 
                        participants = [
                            None
                            ], 
                        status = 'active', 
                        timestamps = smartytalent_client.models.resource_timestamps_schema.ResourceTimestampsSchema(
                            created = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                            modified = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ), ), )
            )
        else:
            return UpdateMeetingRequestBody(
                data = smartytalent_client.models.update_meeting_request_body_data.UpdateMeetingRequestBodyData(
                    type = 'meetings', 
                    id = '', 
                    attributes = smartytalent_client.models.meeting_attributes_schema.MeetingAttributesSchema(
                        title = '', 
                        description = '', 
                        scheduled_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        duration = 56, 
                        media_region = '', 
                        external_meeting_id = '', 
                        chime_meeting_id = '', 
                        chime_meeting_data = smartytalent_client.models.chime_meeting_data.chimeMeetingData(), 
                        participants = [
                            None
                            ], 
                        status = 'active', 
                        timestamps = smartytalent_client.models.resource_timestamps_schema.ResourceTimestampsSchema(
                            created = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                            modified = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ), ), ),
        )
        """

    def testUpdateMeetingRequestBody(self):
        """Test UpdateMeetingRequestBody"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

# flake8: noqa
"""
    SmartyMeet Dev03 API REST

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0.1
    Contact: developer@smartymeet.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501

# import models into model package
from smartytalent_client.models.ad_attributes_schema import AdAttributesSchema
from smartytalent_client.models.ad_attributes_schema_images_inner import AdAttributesSchemaImagesInner
from smartytalent_client.models.ad_relationships_job_data_schema import AdRelationshipsJobDataSchema
from smartytalent_client.models.ad_relationships_job_schema import AdRelationshipsJobSchema
from smartytalent_client.models.ad_relationships_schema import AdRelationshipsSchema
from smartytalent_client.models.ad_resource_schema import AdResourceSchema
from smartytalent_client.models.ad_schema import AdSchema
from smartytalent_client.models.ads_schema import AdsSchema
from smartytalent_client.models.apikey_attributes_schema import ApikeyAttributesSchema
from smartytalent_client.models.apikey_relationships_schema import ApikeyRelationshipsSchema
from smartytalent_client.models.apikey_relationships_user_data_schema import ApikeyRelationshipsUserDataSchema
from smartytalent_client.models.apikey_relationships_user_schema import ApikeyRelationshipsUserSchema
from smartytalent_client.models.apikey_resource_schema import ApikeyResourceSchema
from smartytalent_client.models.apikey_schema import ApikeySchema
from smartytalent_client.models.apikeys_schema import ApikeysSchema
from smartytalent_client.models.assessment_attributes_schema import AssessmentAttributesSchema
from smartytalent_client.models.assessment_relationships_candidate_data_schema import AssessmentRelationshipsCandidateDataSchema
from smartytalent_client.models.assessment_relationships_candidate_schema import AssessmentRelationshipsCandidateSchema
from smartytalent_client.models.assessment_relationships_job_data_schema import AssessmentRelationshipsJobDataSchema
from smartytalent_client.models.assessment_relationships_job_schema import AssessmentRelationshipsJobSchema
from smartytalent_client.models.assessment_relationships_schema import AssessmentRelationshipsSchema
from smartytalent_client.models.assessment_resource_schema import AssessmentResourceSchema
from smartytalent_client.models.assessment_schema import AssessmentSchema
from smartytalent_client.models.assessments_schema import AssessmentsSchema
from smartytalent_client.models.browser_attributes_schema import BrowserAttributesSchema
from smartytalent_client.models.browser_relationships_schema import BrowserRelationshipsSchema
from smartytalent_client.models.browser_relationships_translations_data_schema import BrowserRelationshipsTranslationsDataSchema
from smartytalent_client.models.browser_relationships_translations_schema import BrowserRelationshipsTranslationsSchema
from smartytalent_client.models.browser_resource_schema import BrowserResourceSchema
from smartytalent_client.models.browser_schema import BrowserSchema
from smartytalent_client.models.browsers_schema import BrowsersSchema
from smartytalent_client.models.call_attributes_schema import CallAttributesSchema
from smartytalent_client.models.call_relationships_schema import CallRelationshipsSchema
from smartytalent_client.models.call_relationships_translations_data_schema import CallRelationshipsTranslationsDataSchema
from smartytalent_client.models.call_relationships_translations_schema import CallRelationshipsTranslationsSchema
from smartytalent_client.models.call_resource_schema import CallResourceSchema
from smartytalent_client.models.call_schema import CallSchema
from smartytalent_client.models.calls_schema import CallsSchema
from smartytalent_client.models.candidate_attributes_schema import CandidateAttributesSchema
from smartytalent_client.models.candidate_criteria_schema import CandidateCriteriaSchema
from smartytalent_client.models.candidate_relationships_job_data_schema import CandidateRelationshipsJobDataSchema
from smartytalent_client.models.candidate_relationships_job_schema import CandidateRelationshipsJobSchema
from smartytalent_client.models.candidate_relationships_operations_data_schema import CandidateRelationshipsOperationsDataSchema
from smartytalent_client.models.candidate_relationships_operations_schema import CandidateRelationshipsOperationsSchema
from smartytalent_client.models.candidate_relationships_schema import CandidateRelationshipsSchema
from smartytalent_client.models.candidate_relationships_talent_data_schema import CandidateRelationshipsTalentDataSchema
from smartytalent_client.models.candidate_relationships_talent_schema import CandidateRelationshipsTalentSchema
from smartytalent_client.models.candidate_relationships_translations_data_schema import CandidateRelationshipsTranslationsDataSchema
from smartytalent_client.models.candidate_relationships_translations_schema import CandidateRelationshipsTranslationsSchema
from smartytalent_client.models.candidate_resource_schema import CandidateResourceSchema
from smartytalent_client.models.candidate_schema import CandidateSchema
from smartytalent_client.models.candidates_schema import CandidatesSchema
from smartytalent_client.models.chat_attributes_schema import ChatAttributesSchema
from smartytalent_client.models.chat_relationships_schema import ChatRelationshipsSchema
from smartytalent_client.models.chat_relationships_translations_data_schema import ChatRelationshipsTranslationsDataSchema
from smartytalent_client.models.chat_relationships_translations_schema import ChatRelationshipsTranslationsSchema
from smartytalent_client.models.chat_resource_schema import ChatResourceSchema
from smartytalent_client.models.chat_schema import ChatSchema
from smartytalent_client.models.chats_schema import ChatsSchema
from smartytalent_client.models.conversation_attributes_schema import ConversationAttributesSchema
from smartytalent_client.models.conversation_relationships_candidate_data_schema import ConversationRelationshipsCandidateDataSchema
from smartytalent_client.models.conversation_relationships_candidate_schema import ConversationRelationshipsCandidateSchema
from smartytalent_client.models.conversation_relationships_schema import ConversationRelationshipsSchema
from smartytalent_client.models.conversation_resource_schema import ConversationResourceSchema
from smartytalent_client.models.conversation_schema import ConversationSchema
from smartytalent_client.models.conversations_schema import ConversationsSchema
from smartytalent_client.models.create_ad_request_body import CreateAdRequestBody
from smartytalent_client.models.create_ad_request_body_data import CreateAdRequestBodyData
from smartytalent_client.models.create_apikey_request_body import CreateApikeyRequestBody
from smartytalent_client.models.create_apikey_request_body_data import CreateApikeyRequestBodyData
from smartytalent_client.models.create_assessment_request_body import CreateAssessmentRequestBody
from smartytalent_client.models.create_assessment_request_body_data import CreateAssessmentRequestBodyData
from smartytalent_client.models.create_browser_request_body import CreateBrowserRequestBody
from smartytalent_client.models.create_browser_request_body_data import CreateBrowserRequestBodyData
from smartytalent_client.models.create_call_request_body import CreateCallRequestBody
from smartytalent_client.models.create_call_request_body_data import CreateCallRequestBodyData
from smartytalent_client.models.create_candidate_request_body import CreateCandidateRequestBody
from smartytalent_client.models.create_candidate_request_body_data import CreateCandidateRequestBodyData
from smartytalent_client.models.create_chat_request_body import CreateChatRequestBody
from smartytalent_client.models.create_chat_request_body_data import CreateChatRequestBodyData
from smartytalent_client.models.create_conversation_request_body import CreateConversationRequestBody
from smartytalent_client.models.create_conversation_request_body_data import CreateConversationRequestBodyData
from smartytalent_client.models.create_email_request_body import CreateEmailRequestBody
from smartytalent_client.models.create_email_request_body_data import CreateEmailRequestBodyData
from smartytalent_client.models.create_file_request_body import CreateFileRequestBody
from smartytalent_client.models.create_file_request_body_data import CreateFileRequestBodyData
from smartytalent_client.models.create_finder_request_body import CreateFinderRequestBody
from smartytalent_client.models.create_finder_request_body_data import CreateFinderRequestBodyData
from smartytalent_client.models.create_form_request_body import CreateFormRequestBody
from smartytalent_client.models.create_form_request_body_data import CreateFormRequestBodyData
from smartytalent_client.models.create_job_request_body import CreateJobRequestBody
from smartytalent_client.models.create_job_request_body_data import CreateJobRequestBodyData
from smartytalent_client.models.create_link_request_body import CreateLinkRequestBody
from smartytalent_client.models.create_link_request_body_data import CreateLinkRequestBodyData
from smartytalent_client.models.create_meeting_ai_session_request_body import CreateMeetingAiSessionRequestBody
from smartytalent_client.models.create_meeting_ai_session_request_body_data import CreateMeetingAiSessionRequestBodyData
from smartytalent_client.models.create_meeting_attendee_request_body import CreateMeetingAttendeeRequestBody
from smartytalent_client.models.create_meeting_attendee_request_body_data import CreateMeetingAttendeeRequestBodyData
from smartytalent_client.models.create_meeting_request_body import CreateMeetingRequestBody
from smartytalent_client.models.create_meeting_request_body_data import CreateMeetingRequestBodyData
from smartytalent_client.models.create_note_request_body import CreateNoteRequestBody
from smartytalent_client.models.create_note_request_body_data import CreateNoteRequestBodyData
from smartytalent_client.models.create_notification_request_body import CreateNotificationRequestBody
from smartytalent_client.models.create_notification_request_body_data import CreateNotificationRequestBodyData
from smartytalent_client.models.create_operation_request_body import CreateOperationRequestBody
from smartytalent_client.models.create_operation_request_body_data import CreateOperationRequestBodyData
from smartytalent_client.models.create_persona_request_body import CreatePersonaRequestBody
from smartytalent_client.models.create_persona_request_body_data import CreatePersonaRequestBodyData
from smartytalent_client.models.create_report_request_body import CreateReportRequestBody
from smartytalent_client.models.create_report_request_body_data import CreateReportRequestBodyData
from smartytalent_client.models.create_role_request_body import CreateRoleRequestBody
from smartytalent_client.models.create_role_request_body_data import CreateRoleRequestBodyData
from smartytalent_client.models.create_talent_request_body import CreateTalentRequestBody
from smartytalent_client.models.create_talent_request_body_data import CreateTalentRequestBodyData
from smartytalent_client.models.create_tenant_request_body import CreateTenantRequestBody
from smartytalent_client.models.create_tenant_request_body_data import CreateTenantRequestBodyData
from smartytalent_client.models.create_tenant_upload_request_body import CreateTenantUploadRequestBody
from smartytalent_client.models.create_tenant_upload_request_body_data import CreateTenantUploadRequestBodyData
from smartytalent_client.models.create_tenant_upload_request_body_data_attributes import CreateTenantUploadRequestBodyDataAttributes
from smartytalent_client.models.create_translation_request_body import CreateTranslationRequestBody
from smartytalent_client.models.create_translation_request_body_data import CreateTranslationRequestBodyData
from smartytalent_client.models.create_user_request_body import CreateUserRequestBody
from smartytalent_client.models.create_user_request_body_data import CreateUserRequestBodyData
from smartytalent_client.models.create_user_upload_request_body import CreateUserUploadRequestBody
from smartytalent_client.models.create_user_upload_request_body_data import CreateUserUploadRequestBodyData
from smartytalent_client.models.create_user_upload_request_body_data_attributes import CreateUserUploadRequestBodyDataAttributes
from smartytalent_client.models.create_webhook_request_body import CreateWebhookRequestBody
from smartytalent_client.models.create_webhook_request_body_data import CreateWebhookRequestBodyData
from smartytalent_client.models.email_attributes_schema import EmailAttributesSchema
from smartytalent_client.models.email_relationships_candidate_data_schema import EmailRelationshipsCandidateDataSchema
from smartytalent_client.models.email_relationships_candidate_schema import EmailRelationshipsCandidateSchema
from smartytalent_client.models.email_relationships_operation_data_schema import EmailRelationshipsOperationDataSchema
from smartytalent_client.models.email_relationships_operation_schema import EmailRelationshipsOperationSchema
from smartytalent_client.models.email_relationships_report_data_schema import EmailRelationshipsReportDataSchema
from smartytalent_client.models.email_relationships_report_schema import EmailRelationshipsReportSchema
from smartytalent_client.models.email_relationships_schema import EmailRelationshipsSchema
from smartytalent_client.models.email_relationships_translations_data_schema import EmailRelationshipsTranslationsDataSchema
from smartytalent_client.models.email_relationships_translations_schema import EmailRelationshipsTranslationsSchema
from smartytalent_client.models.email_resource_schema import EmailResourceSchema
from smartytalent_client.models.email_schema import EmailSchema
from smartytalent_client.models.emails_schema import EmailsSchema
from smartytalent_client.models.error_object_schema import ErrorObjectSchema
from smartytalent_client.models.error_schema import ErrorSchema
from smartytalent_client.models.file_attributes_schema import FileAttributesSchema
from smartytalent_client.models.file_relationships_link_data_schema import FileRelationshipsLinkDataSchema
from smartytalent_client.models.file_relationships_link_schema import FileRelationshipsLinkSchema
from smartytalent_client.models.file_relationships_schema import FileRelationshipsSchema
from smartytalent_client.models.file_resource_schema import FileResourceSchema
from smartytalent_client.models.file_schema import FileSchema
from smartytalent_client.models.files_schema import FilesSchema
from smartytalent_client.models.finder_attributes_schema import FinderAttributesSchema
from smartytalent_client.models.finder_relationships_candidates_data_schema import FinderRelationshipsCandidatesDataSchema
from smartytalent_client.models.finder_relationships_candidates_schema import FinderRelationshipsCandidatesSchema
from smartytalent_client.models.finder_relationships_jobs_data_schema import FinderRelationshipsJobsDataSchema
from smartytalent_client.models.finder_relationships_jobs_schema import FinderRelationshipsJobsSchema
from smartytalent_client.models.finder_relationships_schema import FinderRelationshipsSchema
from smartytalent_client.models.finder_relationships_talents_data_schema import FinderRelationshipsTalentsDataSchema
from smartytalent_client.models.finder_relationships_talents_schema import FinderRelationshipsTalentsSchema
from smartytalent_client.models.finder_relationships_users_data_schema import FinderRelationshipsUsersDataSchema
from smartytalent_client.models.finder_relationships_users_schema import FinderRelationshipsUsersSchema
from smartytalent_client.models.finder_resource_schema import FinderResourceSchema
from smartytalent_client.models.finder_schema import FinderSchema
from smartytalent_client.models.finders_schema import FindersSchema
from smartytalent_client.models.form_attributes_schema import FormAttributesSchema
from smartytalent_client.models.form_relationships_schema import FormRelationshipsSchema
from smartytalent_client.models.form_relationships_translations_data_schema import FormRelationshipsTranslationsDataSchema
from smartytalent_client.models.form_relationships_translations_schema import FormRelationshipsTranslationsSchema
from smartytalent_client.models.form_resource_schema import FormResourceSchema
from smartytalent_client.models.form_schema import FormSchema
from smartytalent_client.models.forms_schema import FormsSchema
from smartytalent_client.models.job_attributes_location_item_schema import JobAttributesLocationItemSchema
from smartytalent_client.models.job_attributes_organization_address_schema import JobAttributesOrganizationAddressSchema
from smartytalent_client.models.job_attributes_organization_schema import JobAttributesOrganizationSchema
from smartytalent_client.models.job_attributes_schema import JobAttributesSchema
from smartytalent_client.models.job_attributes_settings_conversation_candidate_interview_schema import JobAttributesSettingsConversationCandidateInterviewSchema
from smartytalent_client.models.job_attributes_settings_conversation_email_contact_schema import JobAttributesSettingsConversationEmailContactSchema
from smartytalent_client.models.job_attributes_settings_conversation_email_delays_schema import JobAttributesSettingsConversationEmailDelaysSchema
from smartytalent_client.models.job_attributes_settings_conversation_email_schema import JobAttributesSettingsConversationEmailSchema
from smartytalent_client.models.job_attributes_settings_conversation_persona_interview_schema import JobAttributesSettingsConversationPersonaInterviewSchema
from smartytalent_client.models.job_attributes_settings_conversation_schema import JobAttributesSettingsConversationSchema
from smartytalent_client.models.job_attributes_settings_criterias_schema import JobAttributesSettingsCriteriasSchema
from smartytalent_client.models.job_attributes_settings_operation_schema import JobAttributesSettingsOperationSchema
from smartytalent_client.models.job_attributes_settings_persona_schema import JobAttributesSettingsPersonaSchema
from smartytalent_client.models.job_attributes_settings_schema import JobAttributesSettingsSchema
from smartytalent_client.models.job_attributes_site_item_schema import JobAttributesSiteItemSchema
from smartytalent_client.models.job_criteria_schema import JobCriteriaSchema
from smartytalent_client.models.job_relationships_candidates_data_schema import JobRelationshipsCandidatesDataSchema
from smartytalent_client.models.job_relationships_candidates_schema import JobRelationshipsCandidatesSchema
from smartytalent_client.models.job_relationships_conversations_data_schema import JobRelationshipsConversationsDataSchema
from smartytalent_client.models.job_relationships_conversations_schema import JobRelationshipsConversationsSchema
from smartytalent_client.models.job_relationships_operations_data_schema import JobRelationshipsOperationsDataSchema
from smartytalent_client.models.job_relationships_operations_schema import JobRelationshipsOperationsSchema
from smartytalent_client.models.job_relationships_personas_data_schema import JobRelationshipsPersonasDataSchema
from smartytalent_client.models.job_relationships_personas_schema import JobRelationshipsPersonasSchema
from smartytalent_client.models.job_relationships_schema import JobRelationshipsSchema
from smartytalent_client.models.job_relationships_translations_data_schema import JobRelationshipsTranslationsDataSchema
from smartytalent_client.models.job_relationships_translations_schema import JobRelationshipsTranslationsSchema
from smartytalent_client.models.job_resource_schema import JobResourceSchema
from smartytalent_client.models.job_schema import JobSchema
from smartytalent_client.models.jobs_schema import JobsSchema
from smartytalent_client.models.link_attributes_schema import LinkAttributesSchema
from smartytalent_client.models.link_relationships_file_data_schema import LinkRelationshipsFileDataSchema
from smartytalent_client.models.link_relationships_file_schema import LinkRelationshipsFileSchema
from smartytalent_client.models.link_relationships_schema import LinkRelationshipsSchema
from smartytalent_client.models.link_resource_schema import LinkResourceSchema
from smartytalent_client.models.link_schema import LinkSchema
from smartytalent_client.models.links_schema import LinksSchema
from smartytalent_client.models.list_candidate_jobs_relationship import ListCandidateJobsRelationship
from smartytalent_client.models.list_candidate_talents_relationship import ListCandidateTalentsRelationship
from smartytalent_client.models.list_job_candidates_relationship import ListJobCandidatesRelationship
from smartytalent_client.models.list_role_users_relationship import ListRoleUsersRelationship
from smartytalent_client.models.list_talent_candidates_relationship import ListTalentCandidatesRelationship
from smartytalent_client.models.list_user_apikeys_relationship import ListUserApikeysRelationship
from smartytalent_client.models.list_user_jobs_relationship import ListUserJobsRelationship
from smartytalent_client.models.list_user_roles_relationship import ListUserRolesRelationship
from smartytalent_client.models.meeting_ai_session_attributes_schema import MeetingAiSessionAttributesSchema
from smartytalent_client.models.meeting_ai_session_attributes_schema_realtime_session import MeetingAiSessionAttributesSchemaRealtimeSession
from smartytalent_client.models.meeting_ai_session_resource_schema import MeetingAiSessionResourceSchema
from smartytalent_client.models.meeting_ai_session_schema import MeetingAiSessionSchema
from smartytalent_client.models.meeting_ai_session_settings_schema import MeetingAiSessionSettingsSchema
from smartytalent_client.models.meeting_attendee_attributes_schema import MeetingAttendeeAttributesSchema
from smartytalent_client.models.meeting_attendee_resource_schema import MeetingAttendeeResourceSchema
from smartytalent_client.models.meeting_attendee_resource_schema_all_of_relationships import MeetingAttendeeResourceSchemaAllOfRelationships
from smartytalent_client.models.meeting_attendee_resource_schema_all_of_relationships_meeting import MeetingAttendeeResourceSchemaAllOfRelationshipsMeeting
from smartytalent_client.models.meeting_attendee_resource_schema_all_of_relationships_meeting_data import MeetingAttendeeResourceSchemaAllOfRelationshipsMeetingData
from smartytalent_client.models.meeting_attendee_response_attributes_schema import MeetingAttendeeResponseAttributesSchema
from smartytalent_client.models.meeting_attendee_schema import MeetingAttendeeSchema
from smartytalent_client.models.meeting_attributes_schema import MeetingAttributesSchema
from smartytalent_client.models.meeting_lobby_attributes_schema import MeetingLobbyAttributesSchema
from smartytalent_client.models.meeting_lobby_resource_schema import MeetingLobbyResourceSchema
from smartytalent_client.models.meeting_lobby_schema import MeetingLobbySchema
from smartytalent_client.models.meeting_relationships_participants_data_schema import MeetingRelationshipsParticipantsDataSchema
from smartytalent_client.models.meeting_relationships_participants_schema import MeetingRelationshipsParticipantsSchema
from smartytalent_client.models.meeting_relationships_schema import MeetingRelationshipsSchema
from smartytalent_client.models.meeting_resource_schema import MeetingResourceSchema
from smartytalent_client.models.meeting_schema import MeetingSchema
from smartytalent_client.models.meeting_transcription_attributes_schema import MeetingTranscriptionAttributesSchema
from smartytalent_client.models.meeting_transcription_request_body import MeetingTranscriptionRequestBody
from smartytalent_client.models.meeting_transcription_request_body_data import MeetingTranscriptionRequestBodyData
from smartytalent_client.models.meeting_transcription_schema import MeetingTranscriptionSchema
from smartytalent_client.models.meeting_transcription_schema_data import MeetingTranscriptionSchemaData
from smartytalent_client.models.meeting_transcription_settings_schema import MeetingTranscriptionSettingsSchema
from smartytalent_client.models.meetings_schema import MeetingsSchema
from smartytalent_client.models.note_attributes_schema import NoteAttributesSchema
from smartytalent_client.models.note_relationships_candidate_data_schema import NoteRelationshipsCandidateDataSchema
from smartytalent_client.models.note_relationships_candidate_schema import NoteRelationshipsCandidateSchema
from smartytalent_client.models.note_relationships_operation_data_schema import NoteRelationshipsOperationDataSchema
from smartytalent_client.models.note_relationships_operation_schema import NoteRelationshipsOperationSchema
from smartytalent_client.models.note_relationships_report_data_schema import NoteRelationshipsReportDataSchema
from smartytalent_client.models.note_relationships_report_schema import NoteRelationshipsReportSchema
from smartytalent_client.models.note_relationships_schema import NoteRelationshipsSchema
from smartytalent_client.models.note_relationships_translations_data_schema import NoteRelationshipsTranslationsDataSchema
from smartytalent_client.models.note_relationships_translations_schema import NoteRelationshipsTranslationsSchema
from smartytalent_client.models.note_resource_schema import NoteResourceSchema
from smartytalent_client.models.note_schema import NoteSchema
from smartytalent_client.models.notes_schema import NotesSchema
from smartytalent_client.models.notification_attributes_schema import NotificationAttributesSchema
from smartytalent_client.models.notification_relationships_schema import NotificationRelationshipsSchema
from smartytalent_client.models.notification_relationships_schema_users import NotificationRelationshipsSchemaUsers
from smartytalent_client.models.notification_relationships_schema_users_data_inner import NotificationRelationshipsSchemaUsersDataInner
from smartytalent_client.models.notification_resource_schema import NotificationResourceSchema
from smartytalent_client.models.notification_schema import NotificationSchema
from smartytalent_client.models.notifications_schema import NotificationsSchema
from smartytalent_client.models.operation_attributes_schema import OperationAttributesSchema
from smartytalent_client.models.operation_relationships_candidate_data_schema import OperationRelationshipsCandidateDataSchema
from smartytalent_client.models.operation_relationships_candidate_schema import OperationRelationshipsCandidateSchema
from smartytalent_client.models.operation_relationships_job_data_schema import OperationRelationshipsJobDataSchema
from smartytalent_client.models.operation_relationships_job_schema import OperationRelationshipsJobSchema
from smartytalent_client.models.operation_relationships_schema import OperationRelationshipsSchema
from smartytalent_client.models.operation_resource_schema import OperationResourceSchema
from smartytalent_client.models.operation_schema import OperationSchema
from smartytalent_client.models.operations_schema import OperationsSchema
from smartytalent_client.models.persona_attributes_schema import PersonaAttributesSchema
from smartytalent_client.models.persona_relationships_candidates_data_schema import PersonaRelationshipsCandidatesDataSchema
from smartytalent_client.models.persona_relationships_candidates_schema import PersonaRelationshipsCandidatesSchema
from smartytalent_client.models.persona_relationships_operations_data_schema import PersonaRelationshipsOperationsDataSchema
from smartytalent_client.models.persona_relationships_operations_schema import PersonaRelationshipsOperationsSchema
from smartytalent_client.models.persona_relationships_schema import PersonaRelationshipsSchema
from smartytalent_client.models.persona_relationships_talents_data_schema import PersonaRelationshipsTalentsDataSchema
from smartytalent_client.models.persona_relationships_talents_schema import PersonaRelationshipsTalentsSchema
from smartytalent_client.models.persona_relationships_translations_data_schema import PersonaRelationshipsTranslationsDataSchema
from smartytalent_client.models.persona_relationships_translations_schema import PersonaRelationshipsTranslationsSchema
from smartytalent_client.models.persona_resource_schema import PersonaResourceSchema
from smartytalent_client.models.persona_schema import PersonaSchema
from smartytalent_client.models.personas_schema import PersonasSchema
from smartytalent_client.models.purchase_tenant_phone_number_request import PurchaseTenantPhoneNumberRequest
from smartytalent_client.models.purchase_tenant_phone_number_request_data import PurchaseTenantPhoneNumberRequestData
from smartytalent_client.models.purchase_tenant_phone_number_request_data_attributes import PurchaseTenantPhoneNumberRequestDataAttributes
from smartytalent_client.models.report_attributes_schema import ReportAttributesSchema
from smartytalent_client.models.report_relationships_schema import ReportRelationshipsSchema
from smartytalent_client.models.report_relationships_tenants_data_schema import ReportRelationshipsTenantsDataSchema
from smartytalent_client.models.report_relationships_tenants_schema import ReportRelationshipsTenantsSchema
from smartytalent_client.models.report_resource_schema import ReportResourceSchema
from smartytalent_client.models.report_schema import ReportSchema
from smartytalent_client.models.reports_schema import ReportsSchema
from smartytalent_client.models.resource_identifier_schema import ResourceIdentifierSchema
from smartytalent_client.models.resource_links_schema import ResourceLinksSchema
from smartytalent_client.models.resource_relationships_links_schema import ResourceRelationshipsLinksSchema
from smartytalent_client.models.resource_relationships_meta_schema import ResourceRelationshipsMetaSchema
from smartytalent_client.models.resource_schema import ResourceSchema
from smartytalent_client.models.resource_timestamps_schema import ResourceTimestampsSchema
from smartytalent_client.models.resources_links_schema import ResourcesLinksSchema
from smartytalent_client.models.resources_meta_page_schema import ResourcesMetaPageSchema
from smartytalent_client.models.resources_meta_schema import ResourcesMetaSchema
from smartytalent_client.models.role_attributes_schema import RoleAttributesSchema
from smartytalent_client.models.role_relationships_permissions_data_schema import RoleRelationshipsPermissionsDataSchema
from smartytalent_client.models.role_relationships_permissions_schema import RoleRelationshipsPermissionsSchema
from smartytalent_client.models.role_relationships_schema import RoleRelationshipsSchema
from smartytalent_client.models.role_relationships_users_data_schema import RoleRelationshipsUsersDataSchema
from smartytalent_client.models.role_relationships_users_schema import RoleRelationshipsUsersSchema
from smartytalent_client.models.role_resource_schema import RoleResourceSchema
from smartytalent_client.models.role_schema import RoleSchema
from smartytalent_client.models.roles_schema import RolesSchema
from smartytalent_client.models.talent_alumni_schema import TalentAlumniSchema
from smartytalent_client.models.talent_attributes_desired_contract_length_schema import TalentAttributesDesiredContractLengthSchema
from smartytalent_client.models.talent_attributes_desired_employment_type_schema import TalentAttributesDesiredEmploymentTypeSchema
from smartytalent_client.models.talent_attributes_desired_role_schema import TalentAttributesDesiredRoleSchema
from smartytalent_client.models.talent_attributes_employment_type_schema import TalentAttributesEmploymentTypeSchema
from smartytalent_client.models.talent_attributes_schema import TalentAttributesSchema
from smartytalent_client.models.talent_attributes_social_link_schema import TalentAttributesSocialLinkSchema
from smartytalent_client.models.talent_availability_received_criteria_schema import TalentAvailabilityReceivedCriteriaSchema
from smartytalent_client.models.talent_received_criteria_schema import TalentReceivedCriteriaSchema
from smartytalent_client.models.talent_referral_schema import TalentReferralSchema
from smartytalent_client.models.talent_referral_schema_referrer import TalentReferralSchemaReferrer
from smartytalent_client.models.talent_relationships_candidates_data_schema import TalentRelationshipsCandidatesDataSchema
from smartytalent_client.models.talent_relationships_candidates_schema import TalentRelationshipsCandidatesSchema
from smartytalent_client.models.talent_relationships_files_data_schema import TalentRelationshipsFilesDataSchema
from smartytalent_client.models.talent_relationships_files_schema import TalentRelationshipsFilesSchema
from smartytalent_client.models.talent_relationships_operations_data_schema import TalentRelationshipsOperationsDataSchema
from smartytalent_client.models.talent_relationships_operations_schema import TalentRelationshipsOperationsSchema
from smartytalent_client.models.talent_relationships_schema import TalentRelationshipsSchema
from smartytalent_client.models.talent_relationships_translations_data_schema import TalentRelationshipsTranslationsDataSchema
from smartytalent_client.models.talent_relationships_translations_schema import TalentRelationshipsTranslationsSchema
from smartytalent_client.models.talent_resource_schema import TalentResourceSchema
from smartytalent_client.models.talent_schema import TalentSchema
from smartytalent_client.models.talents_schema import TalentsSchema
from smartytalent_client.models.tenant_attributes_address_schema import TenantAttributesAddressSchema
from smartytalent_client.models.tenant_attributes_schema import TenantAttributesSchema
from smartytalent_client.models.tenant_attributes_settings_schema import TenantAttributesSettingsSchema
from smartytalent_client.models.tenant_attributes_settings_schema_calling import TenantAttributesSettingsSchemaCalling
from smartytalent_client.models.tenant_resource_schema import TenantResourceSchema
from smartytalent_client.models.tenant_schema import TenantSchema
from smartytalent_client.models.tenant_upload_attributes_schema import TenantUploadAttributesSchema
from smartytalent_client.models.tenant_upload_resource_schema import TenantUploadResourceSchema
from smartytalent_client.models.tenant_upload_schema import TenantUploadSchema
from smartytalent_client.models.tenants_meta_page_schema import TenantsMetaPageSchema
from smartytalent_client.models.tenants_meta_schema import TenantsMetaSchema
from smartytalent_client.models.tenants_schema import TenantsSchema
from smartytalent_client.models.timeline_attributes_schema import TimelineAttributesSchema
from smartytalent_client.models.timeline_attributes_schema_changes_value import TimelineAttributesSchemaChangesValue
from smartytalent_client.models.timeline_attributes_schema_summary_value import TimelineAttributesSchemaSummaryValue
from smartytalent_client.models.timeline_attributes_schema_summary_value_user import TimelineAttributesSchemaSummaryValueUser
from smartytalent_client.models.timeline_attributes_schema_timestamps import TimelineAttributesSchemaTimestamps
from smartytalent_client.models.timeline_resource_schema import TimelineResourceSchema
from smartytalent_client.models.timeline_schema import TimelineSchema
from smartytalent_client.models.timelines_schema import TimelinesSchema
from smartytalent_client.models.translation_attributes_schema import TranslationAttributesSchema
from smartytalent_client.models.translation_relationships_candidate_data_schema import TranslationRelationshipsCandidateDataSchema
from smartytalent_client.models.translation_relationships_candidate_schema import TranslationRelationshipsCandidateSchema
from smartytalent_client.models.translation_relationships_job_data_schema import TranslationRelationshipsJobDataSchema
from smartytalent_client.models.translation_relationships_job_schema import TranslationRelationshipsJobSchema
from smartytalent_client.models.translation_relationships_report_data_schema import TranslationRelationshipsReportDataSchema
from smartytalent_client.models.translation_relationships_report_schema import TranslationRelationshipsReportSchema
from smartytalent_client.models.translation_relationships_schema import TranslationRelationshipsSchema
from smartytalent_client.models.translation_relationships_talent_data_schema import TranslationRelationshipsTalentDataSchema
from smartytalent_client.models.translation_relationships_talent_schema import TranslationRelationshipsTalentSchema
from smartytalent_client.models.translation_resource_schema import TranslationResourceSchema
from smartytalent_client.models.translation_schema import TranslationSchema
from smartytalent_client.models.translations_schema import TranslationsSchema
from smartytalent_client.models.update_ad_request_body import UpdateAdRequestBody
from smartytalent_client.models.update_ad_request_body_data import UpdateAdRequestBodyData
from smartytalent_client.models.update_apikey_request_body import UpdateApikeyRequestBody
from smartytalent_client.models.update_apikey_request_body_data import UpdateApikeyRequestBodyData
from smartytalent_client.models.update_assessment_request_body import UpdateAssessmentRequestBody
from smartytalent_client.models.update_assessment_request_body_data import UpdateAssessmentRequestBodyData
from smartytalent_client.models.update_browser_request_body import UpdateBrowserRequestBody
from smartytalent_client.models.update_browser_request_body_data import UpdateBrowserRequestBodyData
from smartytalent_client.models.update_call_request_body import UpdateCallRequestBody
from smartytalent_client.models.update_call_request_body_data import UpdateCallRequestBodyData
from smartytalent_client.models.update_candidate_request_body import UpdateCandidateRequestBody
from smartytalent_client.models.update_candidate_request_body_data import UpdateCandidateRequestBodyData
from smartytalent_client.models.update_chat_request_body import UpdateChatRequestBody
from smartytalent_client.models.update_chat_request_body_data import UpdateChatRequestBodyData
from smartytalent_client.models.update_conversation_request_body import UpdateConversationRequestBody
from smartytalent_client.models.update_conversation_request_body_data import UpdateConversationRequestBodyData
from smartytalent_client.models.update_email_request_body import UpdateEmailRequestBody
from smartytalent_client.models.update_email_request_body_data import UpdateEmailRequestBodyData
from smartytalent_client.models.update_file_request_body import UpdateFileRequestBody
from smartytalent_client.models.update_file_request_body_data import UpdateFileRequestBodyData
from smartytalent_client.models.update_finder_request_body import UpdateFinderRequestBody
from smartytalent_client.models.update_finder_request_body_data import UpdateFinderRequestBodyData
from smartytalent_client.models.update_form_request_body import UpdateFormRequestBody
from smartytalent_client.models.update_form_request_body_data import UpdateFormRequestBodyData
from smartytalent_client.models.update_job_request_body import UpdateJobRequestBody
from smartytalent_client.models.update_job_request_body_data import UpdateJobRequestBodyData
from smartytalent_client.models.update_link_request_body import UpdateLinkRequestBody
from smartytalent_client.models.update_link_request_body_data import UpdateLinkRequestBodyData
from smartytalent_client.models.update_meeting_request_body import UpdateMeetingRequestBody
from smartytalent_client.models.update_meeting_request_body_data import UpdateMeetingRequestBodyData
from smartytalent_client.models.update_note_request_body import UpdateNoteRequestBody
from smartytalent_client.models.update_note_request_body_data import UpdateNoteRequestBodyData
from smartytalent_client.models.update_notification_request_body import UpdateNotificationRequestBody
from smartytalent_client.models.update_notification_request_body_data import UpdateNotificationRequestBodyData
from smartytalent_client.models.update_notification_request_body_data_attributes import UpdateNotificationRequestBodyDataAttributes
from smartytalent_client.models.update_operation_request_body import UpdateOperationRequestBody
from smartytalent_client.models.update_operation_request_body_data import UpdateOperationRequestBodyData
from smartytalent_client.models.update_persona_request_body import UpdatePersonaRequestBody
from smartytalent_client.models.update_persona_request_body_data import UpdatePersonaRequestBodyData
from smartytalent_client.models.update_report_request_body import UpdateReportRequestBody
from smartytalent_client.models.update_report_request_body_data import UpdateReportRequestBodyData
from smartytalent_client.models.update_role_request_body import UpdateRoleRequestBody
from smartytalent_client.models.update_role_request_body_data import UpdateRoleRequestBodyData
from smartytalent_client.models.update_talent_request_body import UpdateTalentRequestBody
from smartytalent_client.models.update_talent_request_body_data import UpdateTalentRequestBodyData
from smartytalent_client.models.update_tenant_request_body import UpdateTenantRequestBody
from smartytalent_client.models.update_tenant_request_body_data import UpdateTenantRequestBodyData
from smartytalent_client.models.update_translation_request_body import UpdateTranslationRequestBody
from smartytalent_client.models.update_translation_request_body_data import UpdateTranslationRequestBodyData
from smartytalent_client.models.update_user_request_body import UpdateUserRequestBody
from smartytalent_client.models.update_user_request_body_data import UpdateUserRequestBodyData
from smartytalent_client.models.update_webhook_request_body import UpdateWebhookRequestBody
from smartytalent_client.models.update_webhook_request_body_data import UpdateWebhookRequestBodyData
from smartytalent_client.models.user_attributes_schema import UserAttributesSchema
from smartytalent_client.models.user_history_event_schema import UserHistoryEventSchema
from smartytalent_client.models.user_history_event_schema_challenge_responses_inner import UserHistoryEventSchemaChallengeResponsesInner
from smartytalent_client.models.user_history_event_schema_event_feedback import UserHistoryEventSchemaEventFeedback
from smartytalent_client.models.user_relationships_apikeys_data_schema import UserRelationshipsApikeysDataSchema
from smartytalent_client.models.user_relationships_apikeys_schema import UserRelationshipsApikeysSchema
from smartytalent_client.models.user_relationships_jobs_data_schema import UserRelationshipsJobsDataSchema
from smartytalent_client.models.user_relationships_jobs_schema import UserRelationshipsJobsSchema
from smartytalent_client.models.user_relationships_role_data_schema import UserRelationshipsRoleDataSchema
from smartytalent_client.models.user_relationships_role_schema import UserRelationshipsRoleSchema
from smartytalent_client.models.user_relationships_schema import UserRelationshipsSchema
from smartytalent_client.models.user_resource_schema import UserResourceSchema
from smartytalent_client.models.user_schema import UserSchema
from smartytalent_client.models.user_upload_attributes_schema import UserUploadAttributesSchema
from smartytalent_client.models.user_upload_resource_schema import UserUploadResourceSchema
from smartytalent_client.models.user_upload_schema import UserUploadSchema
from smartytalent_client.models.users_schema import UsersSchema
from smartytalent_client.models.webhook_attributes_schema import WebhookAttributesSchema
from smartytalent_client.models.webhook_resource_schema import WebhookResourceSchema
from smartytalent_client.models.webhook_schema import WebhookSchema
from smartytalent_client.models.webhooks_schema import WebhooksSchema




# coding: utf-8

"""
    SmartyMeet Dev03 API REST

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0.1
    Contact: developer@smartymeet.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from smartytalent_client.models.user_upload_schema import UserUploadSchema

class TestUserUploadSchema(unittest.TestCase):
    """UserUploadSchema unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> UserUploadSchema:
        """Test UserUploadSchema
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `UserUploadSchema`
        """
        model = UserUploadSchema()
        if include_optional:
            return UserUploadSchema(
                data = smartytalent_client.models.user_upload_resource_schema.UserUploadResourceSchema(
                    type = 'user-uploads', 
                    id = '', 
                    attributes = smartytalent_client.models.user_upload_attributes_schema.UserUploadAttributesSchema(
                        upload_url = '', 
                        s3_key = '', 
                        url = '', 
                        content_type = '', 
                        purpose = 'avatar', 
                        expires_in = 56, 
                        max_file_size = 56, ), )
            )
        else:
            return UserUploadSchema(
        )
        """

    def testUserUploadSchema(self):
        """Test UserUploadSchema"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    SmartyMeet Dev03 API REST

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0.1
    Contact: developer@smartymeet.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from smartytalent_client.models.tenant_attributes_settings_schema import TenantAttributesSettingsSchema

class TestTenantAttributesSettingsSchema(unittest.TestCase):
    """TenantAttributesSettingsSchema unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> TenantAttributesSettingsSchema:
        """Test TenantAttributesSettingsSchema
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `TenantAttributesSettingsSchema`
        """
        model = TenantAttributesSettingsSchema()
        if include_optional:
            return TenantAttributesSettingsSchema(
                ad = smartytalent_client.models.ad.ad(),
                conversation = smartytalent_client.models.conversation.conversation(),
                report = smartytalent_client.models.report.report(),
                email = smartytalent_client.models.email.email(),
                language = '',
                calling = smartytalent_client.models.tenant_attributes_settings_schema_calling.TenantAttributesSettingsSchema_calling(
                    enabled = True, 
                    twilio_subaccount_sid = '', 
                    twilio_phone_number = '', 
                    twilio_phone_sid = '', 
                    provisioned_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), )
            )
        else:
            return TenantAttributesSettingsSchema(
        )
        """

    def testTenantAttributesSettingsSchema(self):
        """Test TenantAttributesSettingsSchema"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    SmartyMeet Dev03 API REST

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0.1
    Contact: developer@smartymeet.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from smartytalent_client.api.calls_api import CallsApi


class TestCallsApi(unittest.TestCase):
    """CallsApi unit test stubs"""

    def setUp(self) -> None:
        self.api = CallsApi()

    def tearDown(self) -> None:
        pass

    def test_call_options(self) -> None:
        """Test case for call_options

        Call Options
        """
        pass

    def test_calls_options(self) -> None:
        """Test case for calls_options

        Calls Options
        """
        pass

    def test_create_call(self) -> None:
        """Test case for create_call

        Create Call
        """
        pass

    def test_delete_call(self) -> None:
        """Test case for delete_call

        Delete Call
        """
        pass

    def test_list_calls(self) -> None:
        """Test case for list_calls

        List Calls
        """
        pass

    def test_show_call(self) -> None:
        """Test case for show_call

        Show Call
        """
        pass

    def test_update_call(self) -> None:
        """Test case for update_call

        Update Call
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    SmartyMeet Dev03 API REST

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0.1
    Contact: developer@smartymeet.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from smartytalent_client.api.browsers_api import BrowsersApi


class TestBrowsersApi(unittest.TestCase):
    """BrowsersApi unit test stubs"""

    def setUp(self) -> None:
        self.api = BrowsersApi()

    def tearDown(self) -> None:
        pass

    def test_browser_options(self) -> None:
        """Test case for browser_options

        Browser Options
        """
        pass

    def test_browsers_options(self) -> None:
        """Test case for browsers_options

        Browsers Options
        """
        pass

    def test_create_browser(self) -> None:
        """Test case for create_browser

        Create Browser
        """
        pass

    def test_delete_browser(self) -> None:
        """Test case for delete_browser

        Delete Browser
        """
        pass

    def test_list_browsers(self) -> None:
        """Test case for list_browsers

        List Browsers
        """
        pass

    def test_show_browser(self) -> None:
        """Test case for show_browser

        Show Browser
        """
        pass

    def test_update_browser(self) -> None:
        """Test case for update_browser

        Update Browser
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    SmartyMeet Dev03 API REST

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0.1
    Contact: developer@smartymeet.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from smartytalent_client.api.finders_api import FindersApi


class TestFindersApi(unittest.TestCase):
    """FindersApi unit test stubs"""

    def setUp(self) -> None:
        self.api = FindersApi()

    def tearDown(self) -> None:
        pass

    def test_create_finder(self) -> None:
        """Test case for create_finder

        Create Finder
        """
        pass

    def test_delete_finder(self) -> None:
        """Test case for delete_finder

        Delete Finder
        """
        pass

    def test_finder_options(self) -> None:
        """Test case for finder_options

        Finder Options
        """
        pass

    def test_finders_options(self) -> None:
        """Test case for finders_options

        Finders Options
        """
        pass

    def test_list_finders(self) -> None:
        """Test case for list_finders

        List Finders
        """
        pass

    def test_show_finder(self) -> None:
        """Test case for show_finder

        Show Finder
        """
        pass

    def test_update_finder(self) -> None:
        """Test case for update_finder

        Update Finder
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    SmartyMeet Dev03 API REST

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0.1
    Contact: developer@smartymeet.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from smartytalent_client.models.user_history_event_schema import UserHistoryEventSchema

class TestUserHistoryEventSchema(unittest.TestCase):
    """UserHistoryEventSchema unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> UserHistoryEventSchema:
        """Test UserHistoryEventSchema
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `UserHistoryEventSchema`
        """
        model = UserHistoryEventSchema()
        if include_optional:
            return UserHistoryEventSchema(
                event_id = '',
                event_type = 'SignIn',
                timestamp = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                result = 'Pass',
                risk_level = 'Low',
                risk_decision = 'NoRisk',
                compromised_credentials = True,
                challenge_responses = [
                    smartytalent_client.models.user_history_event_schema_challenge_responses_inner.UserHistoryEventSchema_challengeResponses_inner(
                        challenge = '', 
                        result = '', )
                    ],
                ip_address = '',
                device_name = '',
                city = '',
                country = '',
                timezone = '',
                new_device_used = True,
                event_feedback = smartytalent_client.models.user_history_event_schema_event_feedback.UserHistoryEventSchema_eventFeedback(
                    feedback_value = '', 
                    provider = '', )
            )
        else:
            return UserHistoryEventSchema(
        )
        """

    def testUserHistoryEventSchema(self):
        """Test UserHistoryEventSchema"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    SmartyMeet Dev03 API REST

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0.1
    Contact: developer@smartymeet.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from smartytalent_client.api.emails_api import EmailsApi


class TestEmailsApi(unittest.TestCase):
    """EmailsApi unit test stubs"""

    def setUp(self) -> None:
        self.api = EmailsApi()

    def tearDown(self) -> None:
        pass

    def test_create_email(self) -> None:
        """Test case for create_email

        Create Email
        """
        pass

    def test_delete_email(self) -> None:
        """Test case for delete_email

        Delete Email
        """
        pass

    def test_email_options(self) -> None:
        """Test case for email_options

        Email Options
        """
        pass

    def test_emails_options(self) -> None:
        """Test case for emails_options

        Emails Options
        """
        pass

    def test_list_emails(self) -> None:
        """Test case for list_emails

        List Emails
        """
        pass

    def test_show_email(self) -> None:
        """Test case for show_email

        Show Email
        """
        pass

    def test_update_email(self) -> None:
        """Test case for update_email

        Update Email
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    SmartyMeet Dev03 API REST

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0.1
    Contact: developer@smartymeet.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from smartytalent_client.api.jobs_api import JobsApi


class TestJobsApi(unittest.TestCase):
    """JobsApi unit test stubs"""

    def setUp(self) -> None:
        self.api = JobsApi()

    def tearDown(self) -> None:
        pass

    def test_create_job(self) -> None:
        """Test case for create_job

        Create Job
        """
        pass

    def test_delete_job(self) -> None:
        """Test case for delete_job

        Delete Job
        """
        pass

    def test_job_candidates_options(self) -> None:
        """Test case for job_candidates_options

        Job Candidates Options
        """
        pass

    def test_job_candidates_relationships_options(self) -> None:
        """Test case for job_candidates_relationships_options

        Job Candidates Relationships Options
        """
        pass

    def test_job_options(self) -> None:
        """Test case for job_options

        Job Options
        """
        pass

    def test_jobs_options(self) -> None:
        """Test case for jobs_options

        Jobs Options
        """
        pass

    def test_list_job_candidates(self) -> None:
        """Test case for list_job_candidates

        List Job Candidates
        """
        pass

    def test_list_job_candidates_relationship(self) -> None:
        """Test case for list_job_candidates_relationship

        List Job Candidates Relationship
        """
        pass

    def test_list_jobs(self) -> None:
        """Test case for list_jobs

        List Jobs
        """
        pass

    def test_show_job(self) -> None:
        """Test case for show_job

        Show Job
        """
        pass

    def test_update_job(self) -> None:
        """Test case for update_job

        Update Job
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    SmartyMeet Dev03 API REST

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0.1
    Contact: developer@smartymeet.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from smartytalent_client.models.chat_resource_schema import ChatResourceSchema

class TestChatResourceSchema(unittest.TestCase):
    """ChatResourceSchema unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ChatResourceSchema:
        """Test ChatResourceSchema
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ChatResourceSchema`
        """
        model = ChatResourceSchema()
        if include_optional:
            return ChatResourceSchema(
                type = 'chats',
                id = 'bf325375e030fccba00917317c574773-5',
                attributes = smartytalent_client.models.chat_attributes_schema.ChatAttributesSchema(
                    direction = 'inbound', 
                    sender_number = '', 
                    recipient_number = '', 
                    message_sid = '', 
                    body = '', 
                    ai_response = '', 
                    short_code = '', 
                    status = 'active', 
                    timestamps = smartytalent_client.models.resource_timestamps_schema.ResourceTimestampsSchema(
                        created = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        modified = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ), ),
                relationships = smartytalent_client.models.chat_relationships_schema.ChatRelationshipsSchema(
                    translations = smartytalent_client.models.chat_relationships_translations_schema.ChatRelationshipsTranslationsSchema(
                        data = [
                            smartytalent_client.models.chat_relationships_translations_data_schema.ChatRelationshipsTranslationsDataSchema(
                                type = 'translations', 
                                id = '655cde5c9931802df628f3d2de8ca681-2', )
                            ], ), ),
                links = smartytalent_client.models.resource_links_schema.ResourceLinksSchema(
                    self = '', ),
                meta = {
                    'key' : ''
                    }
            )
        else:
            return ChatResourceSchema(
                type = 'chats',
                id = 'bf325375e030fccba00917317c574773-5',
                attributes = smartytalent_client.models.chat_attributes_schema.ChatAttributesSchema(
                    direction = 'inbound', 
                    sender_number = '', 
                    recipient_number = '', 
                    message_sid = '', 
                    body = '', 
                    ai_response = '', 
                    short_code = '', 
                    status = 'active', 
                    timestamps = smartytalent_client.models.resource_timestamps_schema.ResourceTimestampsSchema(
                        created = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        modified = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ), ),
        )
        """

    def testChatResourceSchema(self):
        """Test ChatResourceSchema"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    SmartyMeet Dev03 API REST

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0.1
    Contact: developer@smartymeet.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from smartytalent_client.models.user_attributes_schema import UserAttributesSchema

class TestUserAttributesSchema(unittest.TestCase):
    """UserAttributesSchema unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> UserAttributesSchema:
        """Test UserAttributesSchema
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `UserAttributesSchema`
        """
        model = UserAttributesSchema()
        if include_optional:
            return UserAttributesSchema(
                email = '',
                name = '',
                gender = '',
                locale = '',
                phone = '',
                is_system = True,
                address = { },
                settings = { },
                connections = { },
                avatar_url = '',
                status = '',
                history_events = [
                    smartytalent_client.models.user_history_event_schema.UserHistoryEventSchema(
                        event_id = '', 
                        event_type = 'SignIn', 
                        timestamp = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        result = 'Pass', 
                        risk_level = 'Low', 
                        risk_decision = 'NoRisk', 
                        compromised_credentials = True, 
                        challenge_responses = [
                            smartytalent_client.models.user_history_event_schema_challenge_responses_inner.UserHistoryEventSchema_challengeResponses_inner(
                                challenge = '', 
                                result = '', )
                            ], 
                        ip_address = '', 
                        device_name = '', 
                        city = '', 
                        country = '', 
                        timezone = '', 
                        new_device_used = True, 
                        event_feedback = smartytalent_client.models.user_history_event_schema_event_feedback.UserHistoryEventSchema_eventFeedback(
                            feedback_value = '', 
                            provider = '', ), )
                    ],
                timestamps = smartytalent_client.models.resource_timestamps_schema.ResourceTimestampsSchema(
                    created = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    modified = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), )
            )
        else:
            return UserAttributesSchema(
                email = '',
                name = '',
        )
        """

    def testUserAttributesSchema(self):
        """Test UserAttributesSchema"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    SmartyMeet Dev03 API REST

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0.1
    Contact: developer@smartymeet.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from smartytalent_client.api.notes_api import NotesApi


class TestNotesApi(unittest.TestCase):
    """NotesApi unit test stubs"""

    def setUp(self) -> None:
        self.api = NotesApi()

    def tearDown(self) -> None:
        pass

    def test_create_note(self) -> None:
        """Test case for create_note

        Create Note
        """
        pass

    def test_delete_note(self) -> None:
        """Test case for delete_note

        Delete Note
        """
        pass

    def test_list_notes(self) -> None:
        """Test case for list_notes

        List Notes
        """
        pass

    def test_note_options(self) -> None:
        """Test case for note_options

        Note Options
        """
        pass

    def test_notes_options(self) -> None:
        """Test case for notes_options

        Notes Options
        """
        pass

    def test_show_note(self) -> None:
        """Test case for show_note

        Show Note
        """
        pass

    def test_update_note(self) -> None:
        """Test case for update_note

        Update Note
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    SmartyMeet Dev03 API REST

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0.1
    Contact: developer@smartymeet.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from smartytalent_client.models.job_attributes_schema import JobAttributesSchema

class TestJobAttributesSchema(unittest.TestCase):
    """JobAttributesSchema unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> JobAttributesSchema:
        """Test JobAttributesSchema
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `JobAttributesSchema`
        """
        model = JobAttributesSchema()
        if include_optional:
            return JobAttributesSchema(
                title = {"en-US":"Senior Software Engineer","pl-PL":"Starszy Inżynier Oprogramowania"},
                description = {"en-US":"We are seeking a senior engineer...","pl-PL":"Szukamy starszego inżyniera..."},
                short_code = '',
                source = '',
                language_code = 'en-US',
                status = 'active',
                timestamps = smartytalent_client.models.resource_timestamps_schema.ResourceTimestampsSchema(
                    created = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    modified = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ),
                department = {"en-US":"Engineering","pl-PL":"Inżynieria"},
                specialization = {"en-US":"General Legal Practice","pl-PL":"Ogólna praktyka prawnicza"},
                company_culture = '',
                seniority = '',
                availability = {
                    'key' : smartytalent_client.models.job_criteria_schema.JobCriteriaSchema(
                        name = '', 
                        description = '', 
                        priority = 'low', 
                        priority_confidence = 'low', 
                        priority_reasoning = '', 
                        comparison_rule = '', 
                        expected = [
                            None
                            ], )
                    },
                responsibilities = {"en-US":["Lead and mentor a team","Drive development of solutions"],"pl-PL":["Kierowanie i mentorowanie zespołu","Napędzanie rozwoju rozwiązań"]},
                skills_and_expertise = {
                    'key' : smartytalent_client.models.job_criteria_schema.JobCriteriaSchema(
                        name = '', 
                        description = '', 
                        priority = 'low', 
                        priority_confidence = 'low', 
                        priority_reasoning = '', 
                        comparison_rule = '', 
                        expected = [
                            None
                            ], )
                    },
                languages_spoken = {
                    'key' : smartytalent_client.models.job_criteria_schema.JobCriteriaSchema(
                        name = '', 
                        description = '', 
                        priority = 'low', 
                        priority_confidence = 'low', 
                        priority_reasoning = '', 
                        comparison_rule = '', 
                        expected = [
                            None
                            ], )
                    },
                work_preferences = {
                    'key' : smartytalent_client.models.job_criteria_schema.JobCriteriaSchema(
                        name = '', 
                        description = '', 
                        priority = 'low', 
                        priority_confidence = 'low', 
                        priority_reasoning = '', 
                        comparison_rule = '', 
                        expected = [
                            None
                            ], )
                    },
                location_preferences = {
                    'key' : smartytalent_client.models.job_criteria_schema.JobCriteriaSchema(
                        name = '', 
                        description = '', 
                        priority = 'low', 
                        priority_confidence = 'low', 
                        priority_reasoning = '', 
                        comparison_rule = '', 
                        expected = [
                            None
                            ], )
                    },
                industry_experience = {
                    'key' : smartytalent_client.models.job_criteria_schema.JobCriteriaSchema(
                        name = '', 
                        description = '', 
                        priority = 'low', 
                        priority_confidence = 'low', 
                        priority_reasoning = '', 
                        comparison_rule = '', 
                        expected = [
                            None
                            ], )
                    },
                company_type_experience = {
                    'key' : smartytalent_client.models.job_criteria_schema.JobCriteriaSchema(
                        name = '', 
                        description = '', 
                        priority = 'low', 
                        priority_confidence = 'low', 
                        priority_reasoning = '', 
                        comparison_rule = '', 
                        expected = [
                            None
                            ], )
                    },
                job_positions = {
                    'key' : smartytalent_client.models.job_criteria_schema.JobCriteriaSchema(
                        name = '', 
                        description = '', 
                        priority = 'low', 
                        priority_confidence = 'low', 
                        priority_reasoning = '', 
                        comparison_rule = '', 
                        expected = [
                            None
                            ], )
                    },
                job_tendencies = {
                    'key' : smartytalent_client.models.job_criteria_schema.JobCriteriaSchema(
                        name = '', 
                        description = '', 
                        priority = 'low', 
                        priority_confidence = 'low', 
                        priority_reasoning = '', 
                        comparison_rule = '', 
                        expected = [
                            None
                            ], )
                    },
                keywords = {"en-US":["Python","React","AWS"],"pl-PL":["Python","React","AWS"]},
                work_authorization = {
                    'key' : smartytalent_client.models.job_criteria_schema.JobCriteriaSchema(
                        name = '', 
                        description = '', 
                        priority = 'low', 
                        priority_confidence = 'low', 
                        priority_reasoning = '', 
                        comparison_rule = '', 
                        expected = [
                            None
                            ], )
                    },
                certifications = {
                    'key' : smartytalent_client.models.job_criteria_schema.JobCriteriaSchema(
                        name = '', 
                        description = '', 
                        priority = 'low', 
                        priority_confidence = 'low', 
                        priority_reasoning = '', 
                        comparison_rule = '', 
                        expected = [
                            None
                            ], )
                    },
                licenses = {
                    'key' : smartytalent_client.models.job_criteria_schema.JobCriteriaSchema(
                        name = '', 
                        description = '', 
                        priority = 'low', 
                        priority_confidence = 'low', 
                        priority_reasoning = '', 
                        comparison_rule = '', 
                        expected = [
                            None
                            ], )
                    },
                personality_and_soft_skills = {
                    'key' : smartytalent_client.models.job_criteria_schema.JobCriteriaSchema(
                        name = '', 
                        description = '', 
                        priority = 'low', 
                        priority_confidence = 'low', 
                        priority_reasoning = '', 
                        comparison_rule = '', 
                        expected = [
                            None
                            ], )
                    },
                education = {
                    'key' : smartytalent_client.models.job_criteria_schema.JobCriteriaSchema(
                        name = '', 
                        description = '', 
                        priority = 'low', 
                        priority_confidence = 'low', 
                        priority_reasoning = '', 
                        comparison_rule = '', 
                        expected = [
                            None
                            ], )
                    },
                experience_and_seniority = {
                    'key' : smartytalent_client.models.job_criteria_schema.JobCriteriaSchema(
                        name = '', 
                        description = '', 
                        priority = 'low', 
                        priority_confidence = 'low', 
                        priority_reasoning = '', 
                        comparison_rule = '', 
                        expected = [
                            None
                            ], )
                    },
                benefits = {"en-US":["Private health insurance","Flexible work options"],"pl-PL":["Prywatne ubezpieczenie zdrowotne","Elastyczne opcje pracy"]},
                salary_expectation = {
                    'key' : smartytalent_client.models.job_criteria_schema.JobCriteriaSchema(
                        name = '', 
                        description = '', 
                        priority = 'low', 
                        priority_confidence = 'low', 
                        priority_reasoning = '', 
                        comparison_rule = '', 
                        expected = [
                            None
                            ], )
                    },
                locations = {"en-US":[{"city":"Warsaw","country":"Poland","region":"Masovian"}],"pl-PL":[{"city":"Warszawa","country":"Polska","region":"Mazowieckie"}]},
                sites = {"en-US":[{"siteType":"office"},{"siteType":"hybrid"}],"pl-PL":[{"siteType":"biuro"},{"siteType":"hybrydowy"}]},
                organization = smartytalent_client.models.job_attributes_organization_schema.JobAttributesOrganizationSchema(
                    name = '', 
                    address = smartytalent_client.models.job_attributes_organization_address_schema.JobAttributesOrganizationAddressSchema(
                        city = '', 
                        country = '', 
                        county = '', 
                        postalcode = '', 
                        street = '', ), ),
                settings = smartytalent_client.models.job_attributes_settings_schema.JobAttributesSettingsSchema(
                    conversation = smartytalent_client.models.job_attributes_settings_conversation_schema.JobAttributesSettingsConversationSchema(
                        email = smartytalent_client.models.job_attributes_settings_conversation_email_schema.JobAttributesSettingsConversationEmailSchema(
                            contact = smartytalent_client.models.job_attributes_settings_conversation_email_contact_schema.JobAttributesSettingsConversationEmailContactSchema(
                                cc = [
                                    ''
                                    ], 
                                bcc = [
                                    ''
                                    ], ), 
                            delays = smartytalent_client.models.job_attributes_settings_conversation_email_delays_schema.JobAttributesSettingsConversationEmailDelaysSchema(
                                initial = '', ), 
                            external_sender = True, 
                            is_sendable = True, ), 
                        candidate_interview = smartytalent_client.models.job_attributes_settings_conversation_candidate_interview_schema.JobAttributesSettingsConversationCandidateInterviewSchema(
                            enabled = True, 
                            questions = True, ), 
                        persona_interview = smartytalent_client.models.job_attributes_settings_conversation_persona_interview_schema.JobAttributesSettingsConversationPersonaInterviewSchema(
                            enabled = True, ), 
                        tone = '', ), 
                    criterias = smartytalent_client.models.job_attributes_settings_criterias_schema.JobAttributesSettingsCriteriasSchema(
                        weight = '', 
                        mandatory_criteria_rejection_rating = '', 
                        mandatory_criteria_satisfy_rating = '', ), 
                    operation = smartytalent_client.models.job_attributes_settings_operation_schema.JobAttributesSettingsOperationSchema(
                        change_stage = True, 
                        create_conversation_report = True, 
                        create_note = True, 
                        create_rate = True, 
                        create_tag = True, ), 
                    persona = smartytalent_client.models.job_attributes_settings_persona_schema.JobAttributesSettingsPersonaSchema(
                        weight = '', ), 
                    rating_restrictiveness = '', )
            )
        else:
            return JobAttributesSchema(
                title = {"en-US":"Senior Software Engineer","pl-PL":"Starszy Inżynier Oprogramowania"},
        )
        """

    def testJobAttributesSchema(self):
        """Test JobAttributesSchema"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    SmartyMeet Dev03 API REST

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0.1
    Contact: developer@smartymeet.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from smartytalent_client.api.webhooks_api import WebhooksApi


class TestWebhooksApi(unittest.TestCase):
    """WebhooksApi unit test stubs"""

    def setUp(self) -> None:
        self.api = WebhooksApi()

    def tearDown(self) -> None:
        pass

    def test_create_webhook(self) -> None:
        """Test case for create_webhook

        Create Webhook
        """
        pass

    def test_delete_webhook(self) -> None:
        """Test case for delete_webhook

        Delete Webhook
        """
        pass

    def test_list_webhooks(self) -> None:
        """Test case for list_webhooks

        List Webhooks
        """
        pass

    def test_show_webhook(self) -> None:
        """Test case for show_webhook

        Show Webhook
        """
        pass

    def test_update_webhook(self) -> None:
        """Test case for update_webhook

        Update Webhook
        """
        pass

    def test_webhook_options(self) -> None:
        """Test case for webhook_options

        Webhook Options
        """
        pass

    def test_webhooks_options(self) -> None:
        """Test case for webhooks_options

        Webhooks Options
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    SmartyMeet Dev03 API REST

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0.1
    Contact: developer@smartymeet.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from smartytalent_client.models.create_meeting_attendee_request_body import CreateMeetingAttendeeRequestBody

class TestCreateMeetingAttendeeRequestBody(unittest.TestCase):
    """CreateMeetingAttendeeRequestBody unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> CreateMeetingAttendeeRequestBody:
        """Test CreateMeetingAttendeeRequestBody
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `CreateMeetingAttendeeRequestBody`
        """
        model = CreateMeetingAttendeeRequestBody()
        if include_optional:
            return CreateMeetingAttendeeRequestBody(
                data = smartytalent_client.models.create_meeting_attendee_request_body_data.CreateMeetingAttendeeRequestBodyData(
                    type = 'attendees', 
                    attributes = smartytalent_client.models.meeting_attendee_attributes_schema.MeetingAttendeeAttributesSchema(
                        name = '', 
                        email = '', 
                        role = '', 
                        external_user_id = '', ), )
            )
        else:
            return CreateMeetingAttendeeRequestBody(
                data = smartytalent_client.models.create_meeting_attendee_request_body_data.CreateMeetingAttendeeRequestBodyData(
                    type = 'attendees', 
                    attributes = smartytalent_client.models.meeting_attendee_attributes_schema.MeetingAttendeeAttributesSchema(
                        name = '', 
                        email = '', 
                        role = '', 
                        external_user_id = '', ), ),
        )
        """

    def testCreateMeetingAttendeeRequestBody(self):
        """Test CreateMeetingAttendeeRequestBody"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    SmartyMeet Dev03 API REST

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0.1
    Contact: developer@smartymeet.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from smartytalent_client.models.create_user_request_body_data import CreateUserRequestBodyData

class TestCreateUserRequestBodyData(unittest.TestCase):
    """CreateUserRequestBodyData unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> CreateUserRequestBodyData:
        """Test CreateUserRequestBodyData
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `CreateUserRequestBodyData`
        """
        model = CreateUserRequestBodyData()
        if include_optional:
            return CreateUserRequestBodyData(
                type = 'users',
                attributes = smartytalent_client.models.user_attributes_schema.UserAttributesSchema(
                    email = '', 
                    name = '', 
                    gender = '', 
                    locale = '', 
                    phone = '', 
                    is_system = True, 
                    address = { }, 
                    settings = { }, 
                    connections = { }, 
                    avatar_url = '', 
                    status = '', 
                    history_events = [
                        smartytalent_client.models.user_history_event_schema.UserHistoryEventSchema(
                            event_id = '', 
                            event_type = 'SignIn', 
                            timestamp = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                            result = 'Pass', 
                            risk_level = 'Low', 
                            risk_decision = 'NoRisk', 
                            compromised_credentials = True, 
                            challenge_responses = [
                                smartytalent_client.models.user_history_event_schema_challenge_responses_inner.UserHistoryEventSchema_challengeResponses_inner(
                                    challenge = '', 
                                    result = '', )
                                ], 
                            ip_address = '', 
                            device_name = '', 
                            city = '', 
                            country = '', 
                            timezone = '', 
                            new_device_used = True, 
                            event_feedback = smartytalent_client.models.user_history_event_schema_event_feedback.UserHistoryEventSchema_eventFeedback(
                                feedback_value = '', 
                                provider = '', ), )
                        ], 
                    timestamps = smartytalent_client.models.resource_timestamps_schema.ResourceTimestampsSchema(
                        created = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        modified = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ), ),
                relationships = smartytalent_client.models.user_relationships_schema.UserRelationshipsSchema(
                    role = smartytalent_client.models.user_relationships_role_schema.UserRelationshipsRoleSchema(
                        data = smartytalent_client.models.user_relationships_role_data_schema.UserRelationshipsRoleDataSchema(
                            type = 'roles', 
                            id = '655cde5c9931802df628f3d2de8ca681-1', ), ), 
                    jobs = smartytalent_client.models.user_relationships_jobs_schema.UserRelationshipsJobsSchema(), 
                    apikeys = smartytalent_client.models.user_relationships_apikeys_schema.UserRelationshipsApikeysSchema(), )
            )
        else:
            return CreateUserRequestBodyData(
                type = 'users',
                attributes = smartytalent_client.models.user_attributes_schema.UserAttributesSchema(
                    email = '', 
                    name = '', 
                    gender = '', 
                    locale = '', 
                    phone = '', 
                    is_system = True, 
                    address = { }, 
                    settings = { }, 
                    connections = { }, 
                    avatar_url = '', 
                    status = '', 
                    history_events = [
                        smartytalent_client.models.user_history_event_schema.UserHistoryEventSchema(
                            event_id = '', 
                            event_type = 'SignIn', 
                            timestamp = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                            result = 'Pass', 
                            risk_level = 'Low', 
                            risk_decision = 'NoRisk', 
                            compromised_credentials = True, 
                            challenge_responses = [
                                smartytalent_client.models.user_history_event_schema_challenge_responses_inner.UserHistoryEventSchema_challengeResponses_inner(
                                    challenge = '', 
                                    result = '', )
                                ], 
                            ip_address = '', 
                            device_name = '', 
                            city = '', 
                            country = '', 
                            timezone = '', 
                            new_device_used = True, 
                            event_feedback = smartytalent_client.models.user_history_event_schema_event_feedback.UserHistoryEventSchema_eventFeedback(
                                feedback_value = '', 
                                provider = '', ), )
                        ], 
                    timestamps = smartytalent_client.models.resource_timestamps_schema.ResourceTimestampsSchema(
                        created = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        modified = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ), ),
        )
        """

    def testCreateUserRequestBodyData(self):
        """Test CreateUserRequestBodyData"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    SmartyMeet Dev03 API REST

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0.1
    Contact: developer@smartymeet.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from smartytalent_client.api.triggers_api import TriggersApi


class TestTriggersApi(unittest.TestCase):
    """TriggersApi unit test stubs"""

    def setUp(self) -> None:
        self.api = TriggersApi()

    def tearDown(self) -> None:
        pass

    def test_create_trigger(self) -> None:
        """Test case for create_trigger

        Create Trigger
        """
        pass

    def test_delete_trigger(self) -> None:
        """Test case for delete_trigger

        Delete Trigger
        """
        pass

    def test_list_triggers(self) -> None:
        """Test case for list_triggers

        List Triggers
        """
        pass

    def test_show_trigger(self) -> None:
        """Test case for show_trigger

        Show Trigger
        """
        pass

    def test_update_trigger(self) -> None:
        """Test case for update_trigger

        Update Trigger
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    SmartyMeet Dev03 API REST

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0.1
    Contact: developer@smartymeet.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from smartytalent_client.api.personas_api import PersonasApi


class TestPersonasApi(unittest.TestCase):
    """PersonasApi unit test stubs"""

    def setUp(self) -> None:
        self.api = PersonasApi()

    def tearDown(self) -> None:
        pass

    def test_create_persona(self) -> None:
        """Test case for create_persona

        Create Persona
        """
        pass

    def test_delete_persona(self) -> None:
        """Test case for delete_persona

        Delete Persona
        """
        pass

    def test_list_personas(self) -> None:
        """Test case for list_personas

        List Personas
        """
        pass

    def test_persona_options(self) -> None:
        """Test case for persona_options

        Persona Options
        """
        pass

    def test_personas_options(self) -> None:
        """Test case for personas_options

        Personas Options
        """
        pass

    def test_show_persona(self) -> None:
        """Test case for show_persona

        Show Persona
        """
        pass

    def test_update_persona(self) -> None:
        """Test case for update_persona

        Update Persona
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    SmartyMeet Dev03 API REST

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0.1
    Contact: developer@smartymeet.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from smartytalent_client.models.webhooks_schema import WebhooksSchema

class TestWebhooksSchema(unittest.TestCase):
    """WebhooksSchema unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> WebhooksSchema:
        """Test WebhooksSchema
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `WebhooksSchema`
        """
        model = WebhooksSchema()
        if include_optional:
            return WebhooksSchema(
                data = [
                    null
                    ],
                links = smartytalent_client.models.resources_links_schema.ResourcesLinksSchema(
                    self = '', 
                    related = '', 
                    first = '', 
                    prev = '', 
                    next = '', 
                    last = '', ),
                meta = smartytalent_client.models.resources_meta_schema.ResourcesMetaSchema(
                    page = smartytalent_client.models.resources_meta_page_schema.ResourcesMetaPageSchema(
                        cursor = 'MjhkNDljZTc0MzMxNGExOTgzMThmYzlmMWZhZDE0N2YtMQ==', 
                        size = 2, 
                        number = 2, 
                        total_items = 10, 
                        total_pages = 5, ), 
                    count = smartytalent_client.models.resources_meta_count_schema.ResourcesMetaCountSchema(), )
            )
        else:
            return WebhooksSchema(
        )
        """

    def testWebhooksSchema(self):
        """Test WebhooksSchema"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    SmartyMeet Dev03 API REST

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0.1
    Contact: developer@smartymeet.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from smartytalent_client.api.conversations_api import ConversationsApi


class TestConversationsApi(unittest.TestCase):
    """ConversationsApi unit test stubs"""

    def setUp(self) -> None:
        self.api = ConversationsApi()

    def tearDown(self) -> None:
        pass

    def test_conversation_options(self) -> None:
        """Test case for conversation_options

        Conversation Options
        """
        pass

    def test_conversations_options(self) -> None:
        """Test case for conversations_options

        Conversations Options
        """
        pass

    def test_create_conversation(self) -> None:
        """Test case for create_conversation

        Create Conversation
        """
        pass

    def test_delete_conversation(self) -> None:
        """Test case for delete_conversation

        Delete Conversation
        """
        pass

    def test_list_conversations(self) -> None:
        """Test case for list_conversations

        List Conversations
        """
        pass

    def test_show_conversation(self) -> None:
        """Test case for show_conversation

        Show Conversation
        """
        pass

    def test_update_conversation(self) -> None:
        """Test case for update_conversation

        Update Conversation
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    SmartyMeet Dev03 API REST

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0.1
    Contact: developer@smartymeet.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from smartytalent_client.models.meeting_attendee_resource_schema import MeetingAttendeeResourceSchema

class TestMeetingAttendeeResourceSchema(unittest.TestCase):
    """MeetingAttendeeResourceSchema unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> MeetingAttendeeResourceSchema:
        """Test MeetingAttendeeResourceSchema
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `MeetingAttendeeResourceSchema`
        """
        model = MeetingAttendeeResourceSchema()
        if include_optional:
            return MeetingAttendeeResourceSchema(
                type = 'attendees',
                id = 'bf325375e030fccba00917317c574773-5',
                attributes = smartytalent_client.models.meeting_attendee_response_attributes_schema.MeetingAttendeeResponseAttributesSchema(
                    chime_attendee_id = '', 
                    external_user_id = '', 
                    join_token = '', 
                    name = '', 
                    email = '', 
                    role = '', 
                    chime_meeting_data = smartytalent_client.models.chime_meeting_data.chimeMeetingData(), ),
                relationships = smartytalent_client.models.meeting_attendee_resource_schema_all_of_relationships.MeetingAttendeeResourceSchema_allOf_relationships(
                    meeting = smartytalent_client.models.meeting_attendee_resource_schema_all_of_relationships_meeting.MeetingAttendeeResourceSchema_allOf_relationships_meeting(
                        data = smartytalent_client.models.meeting_attendee_resource_schema_all_of_relationships_meeting_data.MeetingAttendeeResourceSchema_allOf_relationships_meeting_data(
                            type = 'meetings', 
                            id = '', ), ), ),
                links = smartytalent_client.models.resource_links_schema.ResourceLinksSchema(
                    self = '', ),
                meta = {
                    'key' : ''
                    }
            )
        else:
            return MeetingAttendeeResourceSchema(
                type = 'attendees',
                id = 'bf325375e030fccba00917317c574773-5',
                attributes = smartytalent_client.models.meeting_attendee_response_attributes_schema.MeetingAttendeeResponseAttributesSchema(
                    chime_attendee_id = '', 
                    external_user_id = '', 
                    join_token = '', 
                    name = '', 
                    email = '', 
                    role = '', 
                    chime_meeting_data = smartytalent_client.models.chime_meeting_data.chimeMeetingData(), ),
        )
        """

    def testMeetingAttendeeResourceSchema(self):
        """Test MeetingAttendeeResourceSchema"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    SmartyMeet Dev03 API REST

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0.1
    Contact: developer@smartymeet.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from smartytalent_client.models.update_job_request_body import UpdateJobRequestBody

class TestUpdateJobRequestBody(unittest.TestCase):
    """UpdateJobRequestBody unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> UpdateJobRequestBody:
        """Test UpdateJobRequestBody
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `UpdateJobRequestBody`
        """
        model = UpdateJobRequestBody()
        if include_optional:
            return UpdateJobRequestBody(
                data = smartytalent_client.models.update_job_request_body_data.UpdateJobRequestBodyData(
                    type = 'jobs', 
                    id = '', 
                    attributes = smartytalent_client.models.job_attributes_schema.JobAttributesSchema(
                        title = {"en-US":"Senior Software Engineer","pl-PL":"Starszy Inżynier Oprogramowania"}, 
                        description = {"en-US":"We are seeking a senior engineer...","pl-PL":"Szukamy starszego inżyniera..."}, 
                        short_code = '', 
                        source = '', 
                        language_code = 'en-US', 
                        status = 'active', 
                        timestamps = smartytalent_client.models.resource_timestamps_schema.ResourceTimestampsSchema(
                            created = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                            modified = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ), 
                        department = {"en-US":"Engineering","pl-PL":"Inżynieria"}, 
                        specialization = {"en-US":"General Legal Practice","pl-PL":"Ogólna praktyka prawnicza"}, 
                        company_culture = '', 
                        seniority = '', 
                        availability = {
                            'key' : smartytalent_client.models.job_criteria_schema.JobCriteriaSchema(
                                name = '', 
                                description = '', 
                                priority = 'low', 
                                priority_confidence = 'low', 
                                priority_reasoning = '', 
                                comparison_rule = '', 
                                expected = [
                                    None
                                    ], )
                            }, 
                        responsibilities = {"en-US":["Lead and mentor a team","Drive development of solutions"],"pl-PL":["Kierowanie i mentorowanie zespołu","Napędzanie rozwoju rozwiązań"]}, 
                        skills_and_expertise = {
                            'key' : smartytalent_client.models.job_criteria_schema.JobCriteriaSchema(
                                name = '', 
                                description = '', 
                                priority = 'low', 
                                priority_confidence = 'low', 
                                priority_reasoning = '', 
                                comparison_rule = '', )
                            }, 
                        languages_spoken = {
                            'key' : 
                            }, 
                        work_preferences = {
                            'key' : 
                            }, 
                        location_preferences = {
                            'key' : 
                            }, 
                        industry_experience = {
                            'key' : 
                            }, 
                        company_type_experience = {
                            'key' : 
                            }, 
                        job_positions = {
                            'key' : 
                            }, 
                        job_tendencies = {
                            'key' : 
                            }, 
                        keywords = {"en-US":["Python","React","AWS"],"pl-PL":["Python","React","AWS"]}, 
                        work_authorization = {
                            'key' : 
                            }, 
                        certifications = {
                            'key' : 
                            }, 
                        licenses = {
                            'key' : 
                            }, 
                        personality_and_soft_skills = {
                            'key' : 
                            }, 
                        education = {
                            'key' : 
                            }, 
                        experience_and_seniority = {
                            'key' : 
                            }, 
                        benefits = {"en-US":["Private health insurance","Flexible work options"],"pl-PL":["Prywatne ubezpieczenie zdrowotne","Elastyczne opcje pracy"]}, 
                        salary_expectation = {
                            'key' : 
                            }, 
                        locations = {"en-US":[{"city":"Warsaw","country":"Poland","region":"Masovian"}],"pl-PL":[{"city":"Warszawa","country":"Polska","region":"Mazowieckie"}]}, 
                        sites = {"en-US":[{"siteType":"office"},{"siteType":"hybrid"}],"pl-PL":[{"siteType":"biuro"},{"siteType":"hybrydowy"}]}, 
                        organization = smartytalent_client.models.job_attributes_organization_schema.JobAttributesOrganizationSchema(
                            name = '', 
                            address = smartytalent_client.models.job_attributes_organization_address_schema.JobAttributesOrganizationAddressSchema(
                                city = '', 
                                country = '', 
                                county = '', 
                                postalcode = '', 
                                street = '', ), ), 
                        settings = smartytalent_client.models.job_attributes_settings_schema.JobAttributesSettingsSchema(
                            conversation = smartytalent_client.models.job_attributes_settings_conversation_schema.JobAttributesSettingsConversationSchema(
                                email = smartytalent_client.models.job_attributes_settings_conversation_email_schema.JobAttributesSettingsConversationEmailSchema(
                                    contact = smartytalent_client.models.job_attributes_settings_conversation_email_contact_schema.JobAttributesSettingsConversationEmailContactSchema(
                                        cc = [
                                            ''
                                            ], 
                                        bcc = [
                                            ''
                                            ], ), 
                                    delays = smartytalent_client.models.job_attributes_settings_conversation_email_delays_schema.JobAttributesSettingsConversationEmailDelaysSchema(
                                        initial = '', ), 
                                    external_sender = True, 
                                    is_sendable = True, ), 
                                candidate_interview = smartytalent_client.models.job_attributes_settings_conversation_candidate_interview_schema.JobAttributesSettingsConversationCandidateInterviewSchema(
                                    enabled = True, 
                                    questions = True, ), 
                                persona_interview = smartytalent_client.models.job_attributes_settings_conversation_persona_interview_schema.JobAttributesSettingsConversationPersonaInterviewSchema(
                                    enabled = True, ), 
                                tone = '', ), 
                            criterias = smartytalent_client.models.job_attributes_settings_criterias_schema.JobAttributesSettingsCriteriasSchema(
                                weight = '', 
                                mandatory_criteria_rejection_rating = '', 
                                mandatory_criteria_satisfy_rating = '', ), 
                            operation = smartytalent_client.models.job_attributes_settings_operation_schema.JobAttributesSettingsOperationSchema(
                                change_stage = True, 
                                create_conversation_report = True, 
                                create_note = True, 
                                create_rate = True, 
                                create_tag = True, ), 
                            persona = smartytalent_client.models.job_attributes_settings_persona_schema.JobAttributesSettingsPersonaSchema(
                                weight = '', ), 
                            rating_restrictiveness = '', ), ), )
            )
        else:
            return UpdateJobRequestBody(
                data = smartytalent_client.models.update_job_request_body_data.UpdateJobRequestBodyData(
                    type = 'jobs', 
                    id = '', 
                    attributes = smartytalent_client.models.job_attributes_schema.JobAttributesSchema(
                        title = {"en-US":"Senior Software Engineer","pl-PL":"Starszy Inżynier Oprogramowania"}, 
                        description = {"en-US":"We are seeking a senior engineer...","pl-PL":"Szukamy starszego inżyniera..."}, 
                        short_code = '', 
                        source = '', 
                        language_code = 'en-US', 
                        status = 'active', 
                        timestamps = smartytalent_client.models.resource_timestamps_schema.ResourceTimestampsSchema(
                            created = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                            modified = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ), 
                        department = {"en-US":"Engineering","pl-PL":"Inżynieria"}, 
                        specialization = {"en-US":"General Legal Practice","pl-PL":"Ogólna praktyka prawnicza"}, 
                        company_culture = '', 
                        seniority = '', 
                        availability = {
                            'key' : smartytalent_client.models.job_criteria_schema.JobCriteriaSchema(
                                name = '', 
                                description = '', 
                                priority = 'low', 
                                priority_confidence = 'low', 
                                priority_reasoning = '', 
                                comparison_rule = '', 
                                expected = [
                                    None
                                    ], )
                            }, 
                        responsibilities = {"en-US":["Lead and mentor a team","Drive development of solutions"],"pl-PL":["Kierowanie i mentorowanie zespołu","Napędzanie rozwoju rozwiązań"]}, 
                        skills_and_expertise = {
                            'key' : smartytalent_client.models.job_criteria_schema.JobCriteriaSchema(
                                name = '', 
                                description = '', 
                                priority = 'low', 
                                priority_confidence = 'low', 
                                priority_reasoning = '', 
                                comparison_rule = '', )
                            }, 
                        languages_spoken = {
                            'key' : 
                            }, 
                        work_preferences = {
                            'key' : 
                            }, 
                        location_preferences = {
                            'key' : 
                            }, 
                        industry_experience = {
                            'key' : 
                            }, 
                        company_type_experience = {
                            'key' : 
                            }, 
                        job_positions = {
                            'key' : 
                            }, 
                        job_tendencies = {
                            'key' : 
                            }, 
                        keywords = {"en-US":["Python","React","AWS"],"pl-PL":["Python","React","AWS"]}, 
                        work_authorization = {
                            'key' : 
                            }, 
                        certifications = {
                            'key' : 
                            }, 
                        licenses = {
                            'key' : 
                            }, 
                        personality_and_soft_skills = {
                            'key' : 
                            }, 
                        education = {
                            'key' : 
                            }, 
                        experience_and_seniority = {
                            'key' : 
                            }, 
                        benefits = {"en-US":["Private health insurance","Flexible work options"],"pl-PL":["Prywatne ubezpieczenie zdrowotne","Elastyczne opcje pracy"]}, 
                        salary_expectation = {
                            'key' : 
                            }, 
                        locations = {"en-US":[{"city":"Warsaw","country":"Poland","region":"Masovian"}],"pl-PL":[{"city":"Warszawa","country":"Polska","region":"Mazowieckie"}]}, 
                        sites = {"en-US":[{"siteType":"office"},{"siteType":"hybrid"}],"pl-PL":[{"siteType":"biuro"},{"siteType":"hybrydowy"}]}, 
                        organization = smartytalent_client.models.job_attributes_organization_schema.JobAttributesOrganizationSchema(
                            name = '', 
                            address = smartytalent_client.models.job_attributes_organization_address_schema.JobAttributesOrganizationAddressSchema(
                                city = '', 
                                country = '', 
                                county = '', 
                                postalcode = '', 
                                street = '', ), ), 
                        settings = smartytalent_client.models.job_attributes_settings_schema.JobAttributesSettingsSchema(
                            conversation = smartytalent_client.models.job_attributes_settings_conversation_schema.JobAttributesSettingsConversationSchema(
                                email = smartytalent_client.models.job_attributes_settings_conversation_email_schema.JobAttributesSettingsConversationEmailSchema(
                                    contact = smartytalent_client.models.job_attributes_settings_conversation_email_contact_schema.JobAttributesSettingsConversationEmailContactSchema(
                                        cc = [
                                            ''
                                            ], 
                                        bcc = [
                                            ''
                                            ], ), 
                                    delays = smartytalent_client.models.job_attributes_settings_conversation_email_delays_schema.JobAttributesSettingsConversationEmailDelaysSchema(
                                        initial = '', ), 
                                    external_sender = True, 
                                    is_sendable = True, ), 
                                candidate_interview = smartytalent_client.models.job_attributes_settings_conversation_candidate_interview_schema.JobAttributesSettingsConversationCandidateInterviewSchema(
                                    enabled = True, 
                                    questions = True, ), 
                                persona_interview = smartytalent_client.models.job_attributes_settings_conversation_persona_interview_schema.JobAttributesSettingsConversationPersonaInterviewSchema(
                                    enabled = True, ), 
                                tone = '', ), 
                            criterias = smartytalent_client.models.job_attributes_settings_criterias_schema.JobAttributesSettingsCriteriasSchema(
                                weight = '', 
                                mandatory_criteria_rejection_rating = '', 
                                mandatory_criteria_satisfy_rating = '', ), 
                            operation = smartytalent_client.models.job_attributes_settings_operation_schema.JobAttributesSettingsOperationSchema(
                                change_stage = True, 
                                create_conversation_report = True, 
                                create_note = True, 
                                create_rate = True, 
                                create_tag = True, ), 
                            persona = smartytalent_client.models.job_attributes_settings_persona_schema.JobAttributesSettingsPersonaSchema(
                                weight = '', ), 
                            rating_restrictiveness = '', ), ), ),
        )
        """

    def testUpdateJobRequestBody(self):
        """Test UpdateJobRequestBody"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    SmartyMeet Dev03 API REST

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0.1
    Contact: developer@smartymeet.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from smartytalent_client.models.report_schema import ReportSchema

class TestReportSchema(unittest.TestCase):
    """ReportSchema unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ReportSchema:
        """Test ReportSchema
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ReportSchema`
        """
        model = ReportSchema()
        if include_optional:
            return ReportSchema(
                data = None,
                links = smartytalent_client.models.resource_links_schema.ResourceLinksSchema(
                    self = '', ),
                meta = {
                    'key' : ''
                    }
            )
        else:
            return ReportSchema(
        )
        """

    def testReportSchema(self):
        """Test ReportSchema"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# flake8: noqa

# import apis into api package
from smartytalent_client.api.actions_api import ActionsApi
from smartytalent_client.api.ads_api import AdsApi
from smartytalent_client.api.apikeys_api import ApikeysApi
from smartytalent_client.api.assessments_api import AssessmentsApi
from smartytalent_client.api.browsers_api import BrowsersApi
from smartytalent_client.api.calls_api import CallsApi
from smartytalent_client.api.candidates_api import CandidatesApi
from smartytalent_client.api.chats_api import ChatsApi
from smartytalent_client.api.conversations_api import ConversationsApi
from smartytalent_client.api.emails_api import EmailsApi
from smartytalent_client.api.files_api import FilesApi
from smartytalent_client.api.finders_api import FindersApi
from smartytalent_client.api.forms_api import FormsApi
from smartytalent_client.api.jobs_api import JobsApi
from smartytalent_client.api.links_api import LinksApi
from smartytalent_client.api.meetings_api import MeetingsApi
from smartytalent_client.api.notes_api import NotesApi
from smartytalent_client.api.notifications_api import NotificationsApi
from smartytalent_client.api.operations_api import OperationsApi
from smartytalent_client.api.personas_api import PersonasApi
from smartytalent_client.api.reports_api import ReportsApi
from smartytalent_client.api.roles_api import RolesApi
from smartytalent_client.api.runs_api import RunsApi
from smartytalent_client.api.talents_api import TalentsApi
from smartytalent_client.api.tenants_api import TenantsApi
from smartytalent_client.api.timelines_api import TimelinesApi
from smartytalent_client.api.translations_api import TranslationsApi
from smartytalent_client.api.triggers_api import TriggersApi
from smartytalent_client.api.users_api import UsersApi
from smartytalent_client.api.webhooks_api import WebhooksApi
from smartytalent_client.api.workflows_api import WorkflowsApi
from smartytalent_client.api.default_api import DefaultApi




# coding: utf-8

"""
    SmartyMeet Dev03 API REST

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0.1
    Contact: developer@smartymeet.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from smartytalent_client.api.meetings_api import MeetingsApi


class TestMeetingsApi(unittest.TestCase):
    """MeetingsApi unit test stubs"""

    def setUp(self) -> None:
        self.api = MeetingsApi()

    def tearDown(self) -> None:
        pass

    def test_create_meeting(self) -> None:
        """Test case for create_meeting

        Create Meeting
        """
        pass

    def test_create_meeting_ai_session(self) -> None:
        """Test case for create_meeting_ai_session

        Create Meeting AI Session
        """
        pass

    def test_create_meeting_attendee(self) -> None:
        """Test case for create_meeting_attendee

        Create Meeting Attendee
        """
        pass

    def test_delete_meeting(self) -> None:
        """Test case for delete_meeting

        Delete Meeting
        """
        pass

    def test_list_meetings(self) -> None:
        """Test case for list_meetings

        List Meetings
        """
        pass

    def test_meeting_ai_session_options(self) -> None:
        """Test case for meeting_ai_session_options

        Meeting AI Session Options
        """
        pass

    def test_meeting_attendees_options(self) -> None:
        """Test case for meeting_attendees_options

        Meeting Attendees Options
        """
        pass

    def test_meeting_lobby_options(self) -> None:
        """Test case for meeting_lobby_options

        Meeting Lobby Options
        """
        pass

    def test_meeting_options(self) -> None:
        """Test case for meeting_options

        Meeting Options
        """
        pass

    def test_meeting_transcription(self) -> None:
        """Test case for meeting_transcription

        Manage Meeting Transcription
        """
        pass

    def test_meeting_transcription_options(self) -> None:
        """Test case for meeting_transcription_options

        Meeting Transcription Options
        """
        pass

    def test_meetings_options(self) -> None:
        """Test case for meetings_options

        Meetings Options
        """
        pass

    def test_show_meeting(self) -> None:
        """Test case for show_meeting

        Show Meeting
        """
        pass

    def test_show_meeting_lobby(self) -> None:
        """Test case for show_meeting_lobby

        Show Meeting Lobby
        """
        pass

    def test_update_meeting(self) -> None:
        """Test case for update_meeting

        Update Meeting
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    SmartyMeet Dev03 API REST

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0.1
    Contact: developer@smartymeet.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from smartytalent_client.api.forms_api import FormsApi


class TestFormsApi(unittest.TestCase):
    """FormsApi unit test stubs"""

    def setUp(self) -> None:
        self.api = FormsApi()

    def tearDown(self) -> None:
        pass

    def test_create_form(self) -> None:
        """Test case for create_form

        Create Form
        """
        pass

    def test_delete_form(self) -> None:
        """Test case for delete_form

        Delete Form
        """
        pass

    def test_form_options(self) -> None:
        """Test case for form_options

        Form Options
        """
        pass

    def test_forms_options(self) -> None:
        """Test case for forms_options

        Forms Options
        """
        pass

    def test_list_forms(self) -> None:
        """Test case for list_forms

        List Forms
        """
        pass

    def test_show_form(self) -> None:
        """Test case for show_form

        Show Form
        """
        pass

    def test_update_form(self) -> None:
        """Test case for update_form

        Update Form
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    SmartyMeet Dev03 API REST

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0.1
    Contact: developer@smartymeet.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from smartytalent_client.models.notification_attributes_schema import NotificationAttributesSchema

class TestNotificationAttributesSchema(unittest.TestCase):
    """NotificationAttributesSchema unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> NotificationAttributesSchema:
        """Test NotificationAttributesSchema
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `NotificationAttributesSchema`
        """
        model = NotificationAttributesSchema()
        if include_optional:
            return NotificationAttributesSchema(
                title = '',
                subtitle = '',
                category = 'general',
                status = 'unread',
                avatar_icon = '',
                avatar_text = '',
                avatar_image = '',
                avatar_color = 'primary',
                created = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                modified = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f')
            )
        else:
            return NotificationAttributesSchema(
                title = '',
        )
        """

    def testNotificationAttributesSchema(self):
        """Test NotificationAttributesSchema"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    SmartyMeet Dev03 API REST

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0.1
    Contact: developer@smartymeet.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from smartytalent_client.models.update_talent_request_body import UpdateTalentRequestBody

class TestUpdateTalentRequestBody(unittest.TestCase):
    """UpdateTalentRequestBody unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> UpdateTalentRequestBody:
        """Test UpdateTalentRequestBody
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `UpdateTalentRequestBody`
        """
        model = UpdateTalentRequestBody()
        if include_optional:
            return UpdateTalentRequestBody(
                data = smartytalent_client.models.update_talent_request_body_data.UpdateTalentRequestBodyData(
                    type = 'talents', 
                    id = '', 
                    attributes = smartytalent_client.models.talent_attributes_schema.TalentAttributesSchema(
                        status = 'active', 
                        name = '', 
                        email = '', 
                        secondary_email = '', 
                        timestamps = smartytalent_client.models.resource_timestamps_schema.ResourceTimestampsSchema(
                            created = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                            modified = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ), 
                        work_email = '', 
                        phone = '', 
                        work_phone = '', 
                        profile_picture_url = '', 
                        availability = {
                            'key' : smartytalent_client.models.talent_availability_received_criteria_schema.TalentAvailabilityReceivedCriteriaSchema(
                                name = '', 
                                description = '', 
                                priority = 'low', 
                                priority_confidence = 'low', 
                                priority_reasoning = '', 
                                received = [
                                    None
                                    ], )
                            }, 
                        desired_contract_length = smartytalent_client.models.talent_attributes_desired_contract_length_schema.TalentAttributesDesiredContractLengthSchema(
                            duration = '', 
                            is_assumed = True, 
                            confidence = 'Low', 
                            flexibility = '', 
                            reasoning = '', ), 
                        employment_type = smartytalent_client.models.talent_attributes_employment_type_schema.TalentAttributesEmploymentTypeSchema(
                            status = '', 
                            is_assumed = True, 
                            confidence = 'Low', 
                            additional_context = '', 
                            reasoning = '', ), 
                        experience_and_seniority = {
                            'key' : smartytalent_client.models.talent_received_criteria_schema.TalentReceivedCriteriaSchema(
                                name = '', 
                                description = '', )
                            }, 
                        break_reason = '', 
                        quick_insights = {
                            'key' : ''
                            }, 
                        languages_spoken = {
                            'key' : smartytalent_client.models.talent_received_criteria_schema.TalentReceivedCriteriaSchema(
                                name = '', 
                                description = '', )
                            }, 
                        social_links = [
                            smartytalent_client.models.talent_attributes_social_link_schema.TalentAttributesSocialLinkSchema(
                                platform = '', 
                                url = '', )
                            ], 
                        desired_employment_type = [
                            smartytalent_client.models.talent_attributes_desired_employment_type_schema.TalentAttributesDesiredEmploymentTypeSchema(
                                type = '', 
                                is_assumed = True, 
                                confidence = 'Low', 
                                reasoning = '', )
                            ], 
                        desired_role = [
                            smartytalent_client.models.talent_attributes_desired_role_schema.TalentAttributesDesiredRoleSchema(
                                role = '', 
                                level = '', 
                                is_assumed = True, 
                                confidence = 'Low', 
                                reasoning = '', )
                            ], 
                        work_preferences = {
                            'key' : 
                            }, 
                        location_preferences = {
                            'key' : 
                            }, 
                        work_authorization = {
                            'key' : 
                            }, 
                        skills_and_expertise = {
                            'key' : 
                            }, 
                        certifications = {
                            'key' : 
                            }, 
                        licenses = {
                            'key' : 
                            }, 
                        professional_experience = {
                            'key' : 
                            }, 
                        industry_experience = {
                            'key' : 
                            }, 
                        company_type_experience = {
                            'key' : 
                            }, 
                        job_positions = {
                            'key' : 
                            }, 
                        job_tendencies = {
                            'key' : 
                            }, 
                        education = {
                            'key' : 
                            }, 
                        projects_and_achievements = {
                            'key' : 
                            }, 
                        personality_and_soft_skills = {
                            'key' : 
                            }, 
                        hobbies_and_interests = {
                            'key' : [
                                ''
                                ]
                            }, 
                        references = {
                            'key' : 
                            }, 
                        keywords = {
                            'key' : [
                                ''
                                ]
                            }, 
                        performance_reviews = [
                            None
                            ], 
                        personality_tests = { }, 
                        salary_expectation = {
                            'key' : 
                            }, 
                        relocation_willingness = True, 
                        requires_sponsorship = True, 
                        career_break = True, 
                        is_talent_pool = True, 
                        ttl = '', 
                        alumni = smartytalent_client.models.talent_alumni_schema.TalentAlumniSchema(
                            is_former_employee = True, 
                            previous_tenure_months = 1.337, 
                            wants_to_return = True, ), 
                        referral = smartytalent_client.models.talent_referral_schema.TalentReferralSchema(
                            is_referred = True, 
                            referral_code = '', 
                            referrer = smartytalent_client.models.talent_referral_schema_referrer.TalentReferralSchema_referrer(
                                email = '', 
                                full_name = '', ), ), 
                        age = '', 
                        gender = '', 
                        settings = { }, 
                        short_code = '', 
                        source = '', ), )
            )
        else:
            return UpdateTalentRequestBody(
                data = smartytalent_client.models.update_talent_request_body_data.UpdateTalentRequestBodyData(
                    type = 'talents', 
                    id = '', 
                    attributes = smartytalent_client.models.talent_attributes_schema.TalentAttributesSchema(
                        status = 'active', 
                        name = '', 
                        email = '', 
                        secondary_email = '', 
                        timestamps = smartytalent_client.models.resource_timestamps_schema.ResourceTimestampsSchema(
                            created = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                            modified = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ), 
                        work_email = '', 
                        phone = '', 
                        work_phone = '', 
                        profile_picture_url = '', 
                        availability = {
                            'key' : smartytalent_client.models.talent_availability_received_criteria_schema.TalentAvailabilityReceivedCriteriaSchema(
                                name = '', 
                                description = '', 
                                priority = 'low', 
                                priority_confidence = 'low', 
                                priority_reasoning = '', 
                                received = [
                                    None
                                    ], )
                            }, 
                        desired_contract_length = smartytalent_client.models.talent_attributes_desired_contract_length_schema.TalentAttributesDesiredContractLengthSchema(
                            duration = '', 
                            is_assumed = True, 
                            confidence = 'Low', 
                            flexibility = '', 
                            reasoning = '', ), 
                        employment_type = smartytalent_client.models.talent_attributes_employment_type_schema.TalentAttributesEmploymentTypeSchema(
                            status = '', 
                            is_assumed = True, 
                            confidence = 'Low', 
                            additional_context = '', 
                            reasoning = '', ), 
                        experience_and_seniority = {
                            'key' : smartytalent_client.models.talent_received_criteria_schema.TalentReceivedCriteriaSchema(
                                name = '', 
                                description = '', )
                            }, 
                        break_reason = '', 
                        quick_insights = {
                            'key' : ''
                            }, 
                        languages_spoken = {
                            'key' : smartytalent_client.models.talent_received_criteria_schema.TalentReceivedCriteriaSchema(
                                name = '', 
                                description = '', )
                            }, 
                        social_links = [
                            smartytalent_client.models.talent_attributes_social_link_schema.TalentAttributesSocialLinkSchema(
                                platform = '', 
                                url = '', )
                            ], 
                        desired_employment_type = [
                            smartytalent_client.models.talent_attributes_desired_employment_type_schema.TalentAttributesDesiredEmploymentTypeSchema(
                                type = '', 
                                is_assumed = True, 
                                confidence = 'Low', 
                                reasoning = '', )
                            ], 
                        desired_role = [
                            smartytalent_client.models.talent_attributes_desired_role_schema.TalentAttributesDesiredRoleSchema(
                                role = '', 
                                level = '', 
                                is_assumed = True, 
                                confidence = 'Low', 
                                reasoning = '', )
                            ], 
                        work_preferences = {
                            'key' : 
                            }, 
                        location_preferences = {
                            'key' : 
                            }, 
                        work_authorization = {
                            'key' : 
                            }, 
                        skills_and_expertise = {
                            'key' : 
                            }, 
                        certifications = {
                            'key' : 
                            }, 
                        licenses = {
                            'key' : 
                            }, 
                        professional_experience = {
                            'key' : 
                            }, 
                        industry_experience = {
                            'key' : 
                            }, 
                        company_type_experience = {
                            'key' : 
                            }, 
                        job_positions = {
                            'key' : 
                            }, 
                        job_tendencies = {
                            'key' : 
                            }, 
                        education = {
                            'key' : 
                            }, 
                        projects_and_achievements = {
                            'key' : 
                            }, 
                        personality_and_soft_skills = {
                            'key' : 
                            }, 
                        hobbies_and_interests = {
                            'key' : [
                                ''
                                ]
                            }, 
                        references = {
                            'key' : 
                            }, 
                        keywords = {
                            'key' : [
                                ''
                                ]
                            }, 
                        performance_reviews = [
                            None
                            ], 
                        personality_tests = { }, 
                        salary_expectation = {
                            'key' : 
                            }, 
                        relocation_willingness = True, 
                        requires_sponsorship = True, 
                        career_break = True, 
                        is_talent_pool = True, 
                        ttl = '', 
                        alumni = smartytalent_client.models.talent_alumni_schema.TalentAlumniSchema(
                            is_former_employee = True, 
                            previous_tenure_months = 1.337, 
                            wants_to_return = True, ), 
                        referral = smartytalent_client.models.talent_referral_schema.TalentReferralSchema(
                            is_referred = True, 
                            referral_code = '', 
                            referrer = smartytalent_client.models.talent_referral_schema_referrer.TalentReferralSchema_referrer(
                                email = '', 
                                full_name = '', ), ), 
                        age = '', 
                        gender = '', 
                        settings = { }, 
                        short_code = '', 
                        source = '', ), ),
        )
        """

    def testUpdateTalentRequestBody(self):
        """Test UpdateTalentRequestBody"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    SmartyMeet Dev03 API REST

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0.1
    Contact: developer@smartymeet.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from smartytalent_client.models.update_candidate_request_body import UpdateCandidateRequestBody

class TestUpdateCandidateRequestBody(unittest.TestCase):
    """UpdateCandidateRequestBody unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> UpdateCandidateRequestBody:
        """Test UpdateCandidateRequestBody
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `UpdateCandidateRequestBody`
        """
        model = UpdateCandidateRequestBody()
        if include_optional:
            return UpdateCandidateRequestBody(
                data = smartytalent_client.models.update_candidate_request_body_data.UpdateCandidateRequestBodyData(
                    type = 'candidates', 
                    id = '', 
                    attributes = smartytalent_client.models.candidate_attributes_schema.CandidateAttributesSchema(
                        name = '', 
                        email = '', 
                        secondary_email = '', 
                        work_email = '', 
                        phone = '', 
                        work_phone = '', 
                        status = 'active', 
                        stage = 'sourced', 
                        age = '', 
                        gender = '', 
                        source = '', 
                        short_code = '', 
                        language_code = '', 
                        recommendation_status_code = 56, 
                        overall_match_rating = 56, 
                        prev_overall_match_rating = 56, 
                        ttl = '', 
                        timestamps = smartytalent_client.models.resource_timestamps_schema.ResourceTimestampsSchema(
                            created = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                            modified = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ), 
                        alumni = smartytalent_client.models.talent_alumni_schema.TalentAlumniSchema(
                            is_former_employee = True, 
                            previous_tenure_months = 1.337, 
                            wants_to_return = True, ), 
                        referral = smartytalent_client.models.talent_referral_schema.TalentReferralSchema(
                            is_referred = True, 
                            referral_code = '', 
                            referrer = smartytalent_client.models.talent_referral_schema_referrer.TalentReferralSchema_referrer(
                                email = '', 
                                full_name = '', ), ), 
                        job_position_title = {
                            'key' : ''
                            }, 
                        rejection_ticket = {
                            'key' : ''
                            }, 
                        recommendation_status = {
                            'key' : None
                            }, 
                        overall_assessment = {
                            'key' : None
                            }, 
                        next_steps = {
                            'key' : None
                            }, 
                        insights_and_analysis = {
                            'key' : None
                            }, 
                        keywords = {
                            'key' : None
                            }, 
                        availability = {
                            'key' : smartytalent_client.models.candidate_criteria_schema.CandidateCriteriaSchema(
                                name = '', 
                                description = '', 
                                priority = 'low', 
                                priority_confidence = 'low', 
                                priority_reasoning = '', 
                                expected = [
                                    None
                                    ], 
                                received = [
                                    None
                                    ], 
                                weight = '', 
                                rating = 1.337, 
                                prev_rating = 1.337, 
                                data_available = True, 
                                comparison_confidence = '', 
                                comparison_reasoning = '', 
                                is_comparison_assumed = True, )
                            }, 
                        certifications = {
                            'key' : smartytalent_client.models.candidate_criteria_schema.CandidateCriteriaSchema(
                                name = '', 
                                description = '', 
                                priority = 'low', 
                                priority_confidence = 'low', 
                                priority_reasoning = '', 
                                weight = '', 
                                rating = 1.337, 
                                prev_rating = 1.337, 
                                data_available = True, 
                                comparison_confidence = '', 
                                comparison_reasoning = '', 
                                is_comparison_assumed = True, )
                            }, 
                        company_type_experience = {
                            'key' : 
                            }, 
                        education = {
                            'key' : 
                            }, 
                        experience_and_seniority = {
                            'key' : 
                            }, 
                        industry_experience = {
                            'key' : 
                            }, 
                        job_positions = {
                            'key' : 
                            }, 
                        job_tendencies = {
                            'key' : 
                            }, 
                        languages_spoken = {
                            'key' : 
                            }, 
                        licenses = {
                            'key' : 
                            }, 
                        location_preferences = {
                            'key' : 
                            }, 
                        personality_and_soft_skills = {
                            'key' : 
                            }, 
                        salary_expectation = {
                            'key' : 
                            }, 
                        skills_and_expertise = {
                            'key' : 
                            }, 
                        work_authorization = {
                            'key' : 
                            }, 
                        work_preferences = {
                            'key' : 
                            }, ), )
            )
        else:
            return UpdateCandidateRequestBody(
                data = smartytalent_client.models.update_candidate_request_body_data.UpdateCandidateRequestBodyData(
                    type = 'candidates', 
                    id = '', 
                    attributes = smartytalent_client.models.candidate_attributes_schema.CandidateAttributesSchema(
                        name = '', 
                        email = '', 
                        secondary_email = '', 
                        work_email = '', 
                        phone = '', 
                        work_phone = '', 
                        status = 'active', 
                        stage = 'sourced', 
                        age = '', 
                        gender = '', 
                        source = '', 
                        short_code = '', 
                        language_code = '', 
                        recommendation_status_code = 56, 
                        overall_match_rating = 56, 
                        prev_overall_match_rating = 56, 
                        ttl = '', 
                        timestamps = smartytalent_client.models.resource_timestamps_schema.ResourceTimestampsSchema(
                            created = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                            modified = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ), 
                        alumni = smartytalent_client.models.talent_alumni_schema.TalentAlumniSchema(
                            is_former_employee = True, 
                            previous_tenure_months = 1.337, 
                            wants_to_return = True, ), 
                        referral = smartytalent_client.models.talent_referral_schema.TalentReferralSchema(
                            is_referred = True, 
                            referral_code = '', 
                            referrer = smartytalent_client.models.talent_referral_schema_referrer.TalentReferralSchema_referrer(
                                email = '', 
                                full_name = '', ), ), 
                        job_position_title = {
                            'key' : ''
                            }, 
                        rejection_ticket = {
                            'key' : ''
                            }, 
                        recommendation_status = {
                            'key' : None
                            }, 
                        overall_assessment = {
                            'key' : None
                            }, 
                        next_steps = {
                            'key' : None
                            }, 
                        insights_and_analysis = {
                            'key' : None
                            }, 
                        keywords = {
                            'key' : None
                            }, 
                        availability = {
                            'key' : smartytalent_client.models.candidate_criteria_schema.CandidateCriteriaSchema(
                                name = '', 
                                description = '', 
                                priority = 'low', 
                                priority_confidence = 'low', 
                                priority_reasoning = '', 
                                expected = [
                                    None
                                    ], 
                                received = [
                                    None
                                    ], 
                                weight = '', 
                                rating = 1.337, 
                                prev_rating = 1.337, 
                                data_available = True, 
                                comparison_confidence = '', 
                                comparison_reasoning = '', 
                                is_comparison_assumed = True, )
                            }, 
                        certifications = {
                            'key' : smartytalent_client.models.candidate_criteria_schema.CandidateCriteriaSchema(
                                name = '', 
                                description = '', 
                                priority = 'low', 
                                priority_confidence = 'low', 
                                priority_reasoning = '', 
                                weight = '', 
                                rating = 1.337, 
                                prev_rating = 1.337, 
                                data_available = True, 
                                comparison_confidence = '', 
                                comparison_reasoning = '', 
                                is_comparison_assumed = True, )
                            }, 
                        company_type_experience = {
                            'key' : 
                            }, 
                        education = {
                            'key' : 
                            }, 
                        experience_and_seniority = {
                            'key' : 
                            }, 
                        industry_experience = {
                            'key' : 
                            }, 
                        job_positions = {
                            'key' : 
                            }, 
                        job_tendencies = {
                            'key' : 
                            }, 
                        languages_spoken = {
                            'key' : 
                            }, 
                        licenses = {
                            'key' : 
                            }, 
                        location_preferences = {
                            'key' : 
                            }, 
                        personality_and_soft_skills = {
                            'key' : 
                            }, 
                        salary_expectation = {
                            'key' : 
                            }, 
                        skills_and_expertise = {
                            'key' : 
                            }, 
                        work_authorization = {
                            'key' : 
                            }, 
                        work_preferences = {
                            'key' : 
                            }, ), ),
        )
        """

    def testUpdateCandidateRequestBody(self):
        """Test UpdateCandidateRequestBody"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    SmartyMeet Dev03 API REST

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0.1
    Contact: developer@smartymeet.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from smartytalent_client.models.create_meeting_ai_session_request_body import CreateMeetingAiSessionRequestBody

class TestCreateMeetingAiSessionRequestBody(unittest.TestCase):
    """CreateMeetingAiSessionRequestBody unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> CreateMeetingAiSessionRequestBody:
        """Test CreateMeetingAiSessionRequestBody
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `CreateMeetingAiSessionRequestBody`
        """
        model = CreateMeetingAiSessionRequestBody()
        if include_optional:
            return CreateMeetingAiSessionRequestBody(
                data = smartytalent_client.models.create_meeting_ai_session_request_body_data.CreateMeetingAiSessionRequestBodyData(
                    type = 'ai-sessions', 
                    attributes = smartytalent_client.models.meeting_ai_session_settings_schema.MeetingAiSessionSettingsSchema(
                        mode = 'translator', 
                        source_language = '', 
                        target_language = '', 
                        language = '', ), )
            )
        else:
            return CreateMeetingAiSessionRequestBody(
                data = smartytalent_client.models.create_meeting_ai_session_request_body_data.CreateMeetingAiSessionRequestBodyData(
                    type = 'ai-sessions', 
                    attributes = smartytalent_client.models.meeting_ai_session_settings_schema.MeetingAiSessionSettingsSchema(
                        mode = 'translator', 
                        source_language = '', 
                        target_language = '', 
                        language = '', ), ),
        )
        """

    def testCreateMeetingAiSessionRequestBody(self):
        """Test CreateMeetingAiSessionRequestBody"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    SmartyMeet Dev03 API REST

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0.1
    Contact: developer@smartymeet.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from smartytalent_client.models.candidate_criteria_schema import CandidateCriteriaSchema

class TestCandidateCriteriaSchema(unittest.TestCase):
    """CandidateCriteriaSchema unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> CandidateCriteriaSchema:
        """Test CandidateCriteriaSchema
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `CandidateCriteriaSchema`
        """
        model = CandidateCriteriaSchema()
        if include_optional:
            return CandidateCriteriaSchema(
                name = '',
                description = '',
                priority = 'low',
                priority_confidence = 'low',
                priority_reasoning = '',
                expected = [
                    None
                    ],
                received = [
                    None
                    ],
                weight = '',
                rating = 1.337,
                prev_rating = 1.337,
                data_available = True,
                comparison_confidence = '',
                comparison_reasoning = '',
                is_comparison_assumed = True
            )
        else:
            return CandidateCriteriaSchema(
        )
        """

    def testCandidateCriteriaSchema(self):
        """Test CandidateCriteriaSchema"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    SmartyMeet Dev03 API REST

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0.1
    Contact: developer@smartymeet.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from smartytalent_client.api.assessments_api import AssessmentsApi


class TestAssessmentsApi(unittest.TestCase):
    """AssessmentsApi unit test stubs"""

    def setUp(self) -> None:
        self.api = AssessmentsApi()

    def tearDown(self) -> None:
        pass

    def test_assessment_options(self) -> None:
        """Test case for assessment_options

        Assessment Options
        """
        pass

    def test_assessments_options(self) -> None:
        """Test case for assessments_options

        Assessments Options
        """
        pass

    def test_create_assessment(self) -> None:
        """Test case for create_assessment

        Create Assessment
        """
        pass

    def test_delete_assessment(self) -> None:
        """Test case for delete_assessment

        Delete Assessment
        """
        pass

    def test_list_assessments(self) -> None:
        """Test case for list_assessments

        List Assessments
        """
        pass

    def test_show_assessment(self) -> None:
        """Test case for show_assessment

        Show Assessment
        """
        pass

    def test_update_assessment(self) -> None:
        """Test case for update_assessment

        Update Assessment
        """
        pass


if __name__ == '__main__':
    unittest.main()
